# encoding: utf-8
import datetime
from south.db import db
from south.v2 import SchemaMigration
from django.db import models

class Migration(SchemaMigration):

    def forwards(self, orm):
        
        # Adding model 'Poll'
        db.create_table('polls_poll', (
            ('id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('name', self.gf('django.db.models.fields.CharField')(max_length=250, db_index=True)),
            ('slug', self.gf('autoslug.fields.AutoSlugField')(unique=True, max_length=50, populate_from=None, unique_with=(), db_index=True)),

            ('published', self.gf('django.db.models.fields.BooleanField')(default=True)),
            ('description', self.gf('django.db.models.fields.TextField')(blank=True)),
        ))
        db.send_create_signal('polls', ['Poll'])

        # Adding model 'Question'
        db.create_table('polls_question', (
            ('id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('poll', self.gf('django.db.models.fields.related.ForeignKey')(to=orm['polls.Poll'])),
            ('text', self.gf('django.db.models.fields.CharField')(max_length=255, db_index=True)),
            ('order', self.gf('django.db.models.fields.IntegerField')(null=True, blank=True)),
            ('allow_multiple_answers', self.gf('django.db.models.fields.BooleanField')(default=False)),
        ))
        db.send_create_signal('polls', ['Question'])

        # Adding model 'Answer'
        db.create_table('polls_answer', (
            ('id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('question', self.gf('django.db.models.fields.related.ForeignKey')(to=orm['polls.Question'])),
            ('text', self.gf('django.db.models.fields.CharField')(max_length=255, db_index=True)),
        ))
        db.send_create_signal('polls', ['Answer'])

        # Adding model 'Submission'
        db.create_table('polls_submission', (
            ('id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('poll', self.gf('django.db.models.fields.related.ForeignKey')(to=orm['polls.Poll'])),
            ('user', self.gf('django.db.models.fields.related.ForeignKey')(to=orm['auth.User'], null=True)),
            ('foreign_user', self.gf('django.db.models.fields.CharField')(db_index=True, max_length=60, blank=True)),
        ))
        db.send_create_signal('polls', ['Submission'])

        # Adding M2M table for field answers on 'Submission'
        db.create_table('polls_submission_answers', (
            ('id', models.AutoField(verbose_name='ID', primary_key=True, auto_created=True)),
            ('submission', models.ForeignKey(orm['polls.submission'], null=False)),
            ('answer', models.ForeignKey(orm['polls.answer'], null=False))
        ))
        db.create_unique('polls_submission_answers', ['submission_id', 'answer_id'])


    def backwards(self, orm):
        
        # Deleting model 'Poll'
        db.delete_table('polls_poll')

        # Deleting model 'Question'
        db.delete_table('polls_question')

        # Deleting model 'Answer'
        db.delete_table('polls_answer')

        # Deleting model 'Submission'
        db.delete_table('polls_submission')

        # Removing M2M table for field answers on 'Submission'
        db.delete_table('polls_submission_answers')


    models = {
        'auth.group': {
            'Meta': {'object_name': 'Group'},
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'unique': 'True', 'max_length': '80'}),
            'permissions': ('django.db.models.fields.related.ManyToManyField', [], {'to': "orm['auth.Permission']", 'symmetrical': 'False', 'blank': 'True'})
        },
        'auth.permission': {
            'Meta': {'ordering': "('content_type__app_label', 'content_type__model', 'codename')", 'unique_together': "(('content_type', 'codename'),)", 'object_name': 'Permission'},
            'codename': ('django.db.models.fields.CharField', [], {'max_length': '100'}),
            'content_type': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['contenttypes.ContentType']"}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '50'})
        },
        'auth.user': {
            'Meta': {'object_name': 'User'},
            'date_joined': ('django.db.models.fields.DateTimeField', [], {'default': 'datetime.datetime.now'}),
            'email': ('django.db.models.fields.EmailField', [], {'max_length': '75', 'blank': 'True'}),
            'first_name': ('django.db.models.fields.CharField', [], {'max_length': '30', 'blank': 'True'}),
            'groups': ('django.db.models.fields.related.ManyToManyField', [], {'to': "orm['auth.Group']", 'symmetrical': 'False', 'blank': 'True'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'is_active': ('django.db.models.fields.BooleanField', [], {'default': 'True'}),
            'is_staff': ('django.db.models.fields.BooleanField', [], {'default': 'False'}),
            'is_superuser': ('django.db.models.fields.BooleanField', [], {'default': 'False'}),
            'last_login': ('django.db.models.fields.DateTimeField', [], {'default': 'datetime.datetime.now'}),
            'last_name': ('django.db.models.fields.CharField', [], {'max_length': '30', 'blank': 'True'}),
            'password': ('django.db.models.fields.CharField', [], {'max_length': '128'}),
            'user_permissions': ('django.db.models.fields.related.ManyToManyField', [], {'to': "orm['auth.Permission']", 'symmetrical': 'False', 'blank': 'True'}),
            'username': ('django.db.models.fields.CharField', [], {'unique': 'True', 'max_length': '30'})
        },
        'collections.categorization': {
            'Meta': {'object_name': 'Categorization'},
            'category': ('django.db.models.fields.related.ForeignKey', [], {'related_name': "'categorizations'", 'to': "orm['collections.Category']"}),
            'content_type': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['contenttypes.ContentType']"}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'object_id': ('django.db.models.fields.PositiveIntegerField', [], {'db_index': 'True'})
        },
        'collections.category': {
            'Meta': {'unique_together': "(('collection', 'name'),)", 'object_name': 'Category'},
            'active': ('django.db.models.fields.BooleanField', [], {'default': 'True', 'db_index': 'True'}),
            'collection': ('django.db.models.fields.related.ForeignKey', [], {'related_name': "u'collection categories'", 'to': "orm['collections.Collection']"}),
            'description': ('django.db.models.fields.TextField', [], {'null': 'True', 'blank': 'True'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'image': ('filebrowser.fields.FileBrowseField', [], {'max_length': '250', 'blank': 'True'}),
            'level': ('django.db.models.fields.PositiveIntegerField', [], {'db_index': 'True'}),
            'lft': ('django.db.models.fields.PositiveIntegerField', [], {'db_index': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '50'}),
            'parent': ('django.db.models.fields.related.ForeignKey', [], {'blank': 'True', 'related_name': "u'children'", 'null': 'True', 'to': "orm['collections.Category']"}),
            'rght': ('django.db.models.fields.PositiveIntegerField', [], {'db_index': 'True'}),
            'slug': ('autoslug.fields.AutoSlugField', [], {'unique_with': '()', 'max_length': '50', 'populate_from': 'None', 'db_index': 'True'}),
            'tree_id': ('django.db.models.fields.PositiveIntegerField', [], {'db_index': 'True'})
        },
        'collections.collection': {
            'Meta': {'object_name': 'Collection'},
            'content_types': ('django.db.models.fields.related.ManyToManyField', [], {'to': "orm['contenttypes.ContentType']", 'db_index': 'True', 'symmetrical': 'False'}),
            'description': ('django.db.models.fields.TextField', [], {'null': 'True', 'blank': 'True'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'image': ('filebrowser.fields.FileBrowseField', [], {'max_length': '250', 'blank': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'unique': 'True', 'max_length': '50'}),
            'navigation_root': ('django.db.models.fields.BooleanField', [], {'default': 'False'}),
            'slug': ('autoslug.fields.AutoSlugField', [], {'unique_with': '()', 'max_length': '50', 'populate_from': 'None', 'db_index': 'True'}),
            'visible': ('django.db.models.fields.BooleanField', [], {'default': 'True'})
        },
        'contenttypes.contenttype': {
            'Meta': {'ordering': "('name',)", 'unique_together': "(('app_label', 'model'),)", 'object_name': 'ContentType', 'db_table': "'django_content_type'"},
            'app_label': ('django.db.models.fields.CharField', [], {'max_length': '100'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'model': ('django.db.models.fields.CharField', [], {'max_length': '100'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '100'})
        },
        'cyclope.relatedcontent': {
            'Meta': {'ordering': "['order']", 'object_name': 'RelatedContent'},
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'order': ('django.db.models.fields.IntegerField', [], {'db_index': 'True', 'null': 'True', 'blank': 'True'}),
            'other_id': ('django.db.models.fields.PositiveIntegerField', [], {'db_index': 'True'}),
            'other_type': ('django.db.models.fields.related.ForeignKey', [], {'related_name': "'related_contents_rt'", 'to': "orm['contenttypes.ContentType']"}),
            'self_id': ('django.db.models.fields.PositiveIntegerField', [], {'db_index': 'True'}),
            'self_type': ('django.db.models.fields.related.ForeignKey', [], {'related_name': "'related_contents_lt'", 'to': "orm['contenttypes.ContentType']"})
        },
        'polls.answer': {
            'Meta': {'object_name': 'Answer'},
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'question': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['polls.Question']"}),
            'text': ('django.db.models.fields.CharField', [], {'max_length': '255', 'db_index': 'True'})
        },
        'polls.poll': {
            'Meta': {'object_name': 'Poll'},
            'description': ('django.db.models.fields.TextField', [], {'blank': 'True'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '250', 'db_index': 'True'}),
            'published': ('django.db.models.fields.BooleanField', [], {'default': 'True'}),
            'slug': ('autoslug.fields.AutoSlugField', [], {'unique': 'True', 'max_length': '50', 'populate_from': 'None', 'unique_with': '()', 'db_index': 'True'}),

        },
        'polls.question': {
            'Meta': {'ordering': "('order',)", 'object_name': 'Question'},
            'allow_multiple_answers': ('django.db.models.fields.BooleanField', [], {'default': 'False'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'order': ('django.db.models.fields.IntegerField', [], {'null': 'True', 'blank': 'True'}),
            'poll': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['polls.Poll']"}),
            'text': ('django.db.models.fields.CharField', [], {'max_length': '255', 'db_index': 'True'})
        },
        'polls.submission': {
            'Meta': {'ordering': "('poll', 'user')", 'object_name': 'Submission'},
            'answers': ('django.db.models.fields.related.ManyToManyField', [], {'to': "orm['polls.Answer']", 'symmetrical': 'False'}),
            'foreign_user': ('django.db.models.fields.CharField', [], {'db_index': 'True', 'max_length': '60', 'blank': 'True'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'poll': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['polls.Poll']"}),
            'user': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['auth.User']", 'null': 'True'})
        }
    }

    complete_apps = ['polls']



from django.utils.translation import ugettext_lazy as _
from django.http import HttpResponse
from django.template import loader

from cyclope.core import frontend
from cyclope.apps.newsletter.models import Newsletter
from cyclope.core.collections.models import Category, Categorization

class NewsletterContentTeasers(frontend.FrontendView):
    """Teaser list for a Newsletter rendered as a table"""
    name='content_teasers_as_table'
    verbose_name=_('show content teasers linked to the website')
    is_default = True
    is_instance_view = True
    is_content_view = True
    is_region_view = False

    template = "newsletter/content_teasers.html"

    def get_response(self, request, req_context, options, content_object):
        newsletter = content_object
        category = newsletter.content_category
        categorizations_list = Categorization.objects.get_for_category(category, 'creation_date')

        req_context.update({'category': category,
                            'newsletter': newsletter,
                            'categorizations': categorizations_list,
                            'inline_view_name': 'newsletter_teaser',
                            })
        t = loader.get_template(self.template)
        return t.render(req_context)

frontend.site.register_view(Newsletter, NewsletterContentTeasers)


class NewsletterContent(NewsletterContentTeasers):
    """Teaser list for a Newsletter rendered as a table"""
    name='content'
    verbose_name=_('show the full content (no external links)')
    is_default = False
    is_instance_view = True
    is_content_view = True
    is_region_view = False

    template = "newsletter/content.html"

frontend.site.register_view(Newsletter, NewsletterContent)

## class NewsletterHeader(frontend.FrontendView):
##     """Header of a Newsletter"""
##     name='header'
##     verbose_name=_('Header')
##     is_instance_view = True
##     is_region_view = True

##     def get_response(self, request, req_context, options, content_object):
##         newsletter = content_object
##         return newsletter.header

## frontend.site.register_view(Newsletter, NewsletterHeader)



#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
# Copyright 2012 Código Sur Sociedad Civil.
# All rights reserved.
#
# This file is part of Cyclope.
#
# Cyclope is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Cyclope is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.


from django import forms
from django.utils.translation import ugettext_lazy as _
from django.template.loader import render_to_string
from cyclope.core import frontend
from models import CustomComment

class CommentsListOptions(forms.Form):
    limit_to_n_items = forms.IntegerField(label=_('Items to show'), min_value=1,
                                          initial=5)

class CommentsList(frontend.FrontendView):
    """Show a list of the last comments
    """
    name='list'
    verbose_name=_('list of the last site content comments')
    is_default = True
    is_instance_view = False
    is_region_view = True
    options_form = CommentsListOptions

    def get_response(self, request, req_context, options):
        limit = options["limit_to_n_items"]
        qs = CustomComment.objects.filter(is_public=True, is_removed=False)
        comment_list = qs.order_by('-submit_date')[:limit]
        req_context.update({'comment_list': comment_list})
        return render_to_string("comments/comments_list.html",
                                context_instance=req_context)

frontend.site.register_view(CustomComment, CommentsList)



#!/usr/bin/env python
# -*- coding: UTF-8 -*-
#
# Copyright 2012 Código Sur Sociedad Civil.
# All rights reserved.
#
# This file is part of Cyclope.
#
# Cyclope is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Cyclope is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from django import forms
from django.contrib.auth.models import User
from django.utils.translation import ugettext_lazy as _

from crispy_forms.helper import FormHelper
from crispy_forms.layout import Submit, Layout, Fieldset, ButtonHolder

from models import UserProfile

class UserProfileForm(forms.ModelForm):
    def __init__(self, *args, **kwargs):
        self.helper = FormHelper()
        self.helper.add_input(Submit('submit', _('Submit')))
        self.helper.layout = Layout(
            Fieldset(
                _('Personal information'),
                'first_name',
                'last_name',
                'email',
                'image',
                'description',
            )
        )
        super(UserProfileForm, self).__init__(*args, **kwargs)
        # Add User's fields first in the form
        self.fields.keyOrder =  ['first_name', 'last_name', 'email'] + self.fields.keyOrder[:-3]
        try:
            self.fields['email'].initial = self.instance.user.email
            self.fields['first_name'].initial = self.instance.user.first_name
            self.fields['last_name'].initial = self.instance.user.last_name
        except User.DoesNotExist:
            del self.fields['email']

    first_name = forms.CharField(label=_('First name'), max_length=30, required=False)
    last_name = forms.CharField(label=_('Last name'), max_length=30, required=False)
    email = forms.EmailField()

    class Meta:
        model = UserProfile
        exclude = ('user',)

    def save(self, *args, **kwargs):
        user = self.instance.user if self.instance.user_id else None
        if user:
            user.first_name = self.cleaned_data['first_name']
            user.last_name = self.cleaned_data['last_name']
            # change the email only if nobody is using it
            email = self.cleaned_data.get('email')
            if email:
                user_same_email = User.objects.filter(email=email)
                if not user_same_email:
                    email = self.cleaned_data['email']
                elif user == user_same_email:
                    email = self.cleaned_data['email']
                else:
                    email = user.email
                user.email = email
            user.save()
            self.instance._form = None

        profile = super(UserProfileForm, self).save(*args, **kwargs)
        # This is a hack to deal with profiles that aren't created automatically by a signal
        # so the user is not part of the profile instance in the save method
        # Instead, the form save will be issued from the profile model
        profile._form = getattr(self.instance, "_form", self)
        return profile



#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
# Copyright 2010 Código Sur - Nuestra América Asoc. Civil / Fundación Pacificar.
# All rights reserved.
#
# This file is part of Cyclope.
#
# Cyclope is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Cyclope is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

class LayoutMiddleware(object):
    """
    Sets session['layout'] if the current menu item has a persistent layout
    and clears it when another menu_item changes the layout.
    """
    def process_request(self, request):
        import cyclope # Leave this here, it prevents circular imports
        import cyclope.settings # Leave this here

        menu_item = cyclope.utils.menu_item_for_request(request)
        if menu_item:
            ## we force the layout for items with custom URL (external apps)
            ## so they can use the correct template to extend from
            if menu_item.persistent_layout or menu_item.custom_url:
                layout = menu_item.get_layout()
                request.session['layout'] = layout
                request.session['layout_template'] = layout.get_template_path()

            else:
                if request.session.has_key('layout'):
                    del request.session['layout']
        else:
            ## if no layout_template has been set we set it to the default so external apps'
            ## templates that extend from request.session.layout_template won't break
            ## even when accessed through a direct URL
            if not 'layout_template' in request.session and \
                   hasattr(cyclope.settings, 'CYCLOPE_DEFAULT_TEMPLATE'):
                request.session['layout_template'] = cyclope.settings.CYCLOPE_DEFAULT_TEMPLATE





from django import forms
from django.shortcuts import render
from django.http import HttpResponseRedirect, HttpResponseForbidden
from django.contrib.contenttypes.models import ContentType
from django.contrib.auth.decorators import login_required
from cyclope.utils import CrispyFormsSimpleMixin
from models import AbuseReportElement


class ReportElementForm(forms.ModelForm, CrispyFormsSimpleMixin):
    class Meta:
        model = AbuseReportElement
        fields = ('abuse_type', 'text')


@login_required
def abuse_report(request, ct_id, obj_id):
    ct = ContentType.objects.get_for_id(ct_id)
    obj = ct.get_object_for_this_type(pk=obj_id)
    # already reported by this user
    if AbuseReportElement.objects.filter(user=request.user, object_id=obj_id,
                                          content_type=ct):
        return render(request, "abuse/report.html", {"already_reported": True, "content": obj})

    if request.method == "POST":
        form = ReportElementForm(request.POST)
        if form.is_valid():
            report_el = form.save(commit=False)
            report_el.content_object = obj
            report_el.user = request.user
            report_el.save()
            return render(request, "abuse/report.html", {"content": obj})
    else:
        form = ReportElementForm()

    return render(request, "abuse/report.html", {
                "form": form,
            })



#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
# Copyright 2010 Código Sur - Nuestra América Asoc. Civil / Fundación Pacificar.
# All rights reserved.
#
# This file is part of Cyclope.
#
# Cyclope is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Cyclope is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from datetime import datetime
from django import forms
from django.utils.translation import ugettext_lazy as _

from cyclope.core import frontend
from cyclope import views
from cyclope import settings as cyc_settings
import feedparser

from models import Feed

# timedelta.total_seconds is new in python 2.7 http://docs.python.org/library/datetime.html
# so we define an equivalent here for compatibility's sake
def total_seconds(td):
    return (td.microseconds + (td.seconds + td.days * 24 * 3600) * 10**6) / 10**6


class FeedDetailOptions(forms.Form):
    limit_to_n_items = forms.IntegerField(label=_('entries to show'), required=False)
    titles_only = forms.BooleanField(label=_('show titles only'), initial=False, required=False)

class FeedDetail(frontend.FrontendView):
    """Detail view for Feeds"""
    name='detail'
    verbose_name=_('detailed view of the selected Feed')
    is_default = True
    is_instance_view = True
    is_content_view = True
    is_region_view = True
    options_form = FeedDetailOptions

    _feed_cache = {}

    def get_response(self, request, req_context, options, content_object):
        if not options['limit_to_n_items']:
            options['limit_to_n_items'] = content_object.number_of_entries
        if not options['titles_only']:
            options['titles_only'] = content_object.titles_only

        now = datetime.now()
        d, last_access = self._feed_cache.get(content_object.url, (None, None))
        if d is None or total_seconds(now - last_access) > cyc_settings.CYCLOPE_FEED_CACHE_TIME:
            d = feedparser.parse(content_object.url)
            self._feed_cache[content_object.url] = (d, now)
        context = {'entries': d.entries[:options['limit_to_n_items']]}
        return views.object_detail(request, req_context, content_object,
                                   extra_context=context)

frontend.site.register_view(Feed, FeedDetail)




#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
# Copyright 2010-2012 Código Sur Sociedad Civil
# All rights reserved.
#
# This file is part of Cyclope.
#
# Cyclope is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Cyclope is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

"""This file holds default values related to settings that need to change when
a new app is installed.
"""

import os
ugettext = lambda s: s

#workaround for PIL when importing Image using different methods.
# see http://jaredforsyth.com/blog/2010/apr/28/accessinit-hash-collision-3-both-1-and-1/
# and https://sourceforge.net/tracker/?func=detail&atid=422030&aid=2993756&group_id=38414
import sys
import PIL.Image
sys.modules['Image'] = PIL.Image

SITE_ID = 1
USE_I18N = True
USE_L10N = True

## LANGUAGE_CODE = 'en'
LANGUAGES = (
    ('es', u'Español'),
    ('en', u'English'),
    ('pt', u'Português'),
    ('it', u'Italiano'),
)

# List of callables that know how to import templates from various sources.
TEMPLATE_LOADERS = (
    'django.template.loaders.filesystem.Loader',
    'django.template.loaders.app_directories.Loader',
    'django.template.loaders.eggs.Loader',
)

TEMPLATE_CONTEXT_PROCESSORS = (
    "django.contrib.auth.context_processors.auth",
    "django.core.context_processors.debug",
    "django.core.context_processors.i18n",
    "django.core.context_processors.media",
    "django.contrib.messages.context_processors.messages",
    "django.core.context_processors.request",
    "cyclope.core.context_processors.site_settings",
    "cyclope.core.context_processors.compressor",
)


MIDDLEWARE_CLASSES = (
    'django.middleware.common.CommonMiddleware',
    'django.middleware.csrf.CsrfViewMiddleware',
    'django.contrib.sessions.middleware.SessionMiddleware',
    'django.contrib.auth.middleware.AuthenticationMiddleware',
    'django.contrib.messages.middleware.MessageMiddleware',
    'django.middleware.locale.LocaleMiddleware',
    'cyclope.middleware.LayoutMiddleware',
#    'debug_toolbar.middleware.DebugToolbarMiddleware',

)

# the order of the INSTALLED_APPS is relevant to get the template load order right
INSTALLED_APPS = [
    'dbgettext',
    'rosetta',
    'haystack',

    'cyclope',
    'cyclope.core.collections',
    'cyclope.core.series',
    'cyclope.core.perms',
    'cyclope.core.user_profiles',
    'cyclope.apps.articles',
    'cyclope.apps.staticpages',
    'cyclope.apps.medialibrary',
    'cyclope.apps.polls',
    'cyclope.apps.forum',
    'cyclope.apps.newsletter',
    'cyclope.apps.contacts',
    'cyclope.apps.locations',
    'cyclope.apps.feeds',
    'cyclope.apps.dynamicforms',
    'cyclope.apps.abuse',
    'cyclope.apps.related_admin',
    'cyclope.apps.custom_comments',

    'admin_tools',
    'admin_tools.theming',
    'admin_tools.menu',
    'admin_tools.dashboard',

    'threadedcomments',

    'django.contrib.auth',
    'django.contrib.contenttypes',
    'django.contrib.sessions',
    'django.contrib.sites',
    'django.contrib.humanize',
    'django.contrib.admin',
    'django.contrib.comments',
    'django.contrib.markup',
    'django.contrib.messages',
    'django.contrib.sitemaps',

    'autoslug',
    'mptt_tree_editor',
    'mptt',
    'captcha',
    'filebrowser',
    'south',
    'registration',
    'profiles',
    'contact_form',
    'markitup',
    'forms_builder.forms',
    'crispy_forms',
    'compressor',
    'ratings',

#    'debug_toolbar',
#    'django_extensions',
]

AUTHENTICATION_BACKENDS = (
    'django.contrib.auth.backends.ModelBackend',
    'cyclope.core.perms.backends.CategoryPermBackend',
)

# ADMIN_MEDIA_PREFIX is deprecated but it's here
# only for compatibility with admin tools 0.4.1
ADMIN_MEDIA_PREFIX = "/media/admin/"

MESSAGE_STORAGE = 'django.contrib.messages.storage.cookie.CookieStorage'

# debug_toolbar settings
#DEBUG_TOOLBAR_CONFIG = {'INTERCEPT_REDIRECTS': False}

# comments settings
COMMENTS_APP = 'cyclope.apps.custom_comments'

EMAIL_SUBJECT_PREFIX = '[Cyclope] '

# captcha settings
CAPTCHA_NOISE_FUNCTIONS=('captcha.helpers.noise_arcs',)
CAPTCHA_FONT_SIZE=30
CAPTCHA_LETTER_ROTATION=(-15,15)

# filebrowser settings
FILEBROWSER_DEBUG = False
FILEBROWSER_DIRECTORY = 'uploads/'
FILEBROWSER_EXTENSIONS = {
    'Folder': [''],
    'Image': ['.jpg','.jpeg','.gif','.png','.tif','.tiff'],
    'Video': ['.ogv', '.mov','.wmv','.mpeg','.mpg','.avi','.rm', '.flv',],
    'Document': ['.odt', 'docx', '.pdf','.doc','.rtf','.txt',
                 '.ods', '.xls', '.xlsx', '.csv', '.ppt', '.pptx'],
    'Audio': ['.ogg', '.oga', '.mp3','.mp4','.wav','.aiff','.midi','.m4p'],
    'Code': ['.html','.py','.js','.css'],
    'Flash_App': ['.swf',],
    'Flash_Movie': ['.flv',],
}

FILEBROWSER_SELECT_FORMATS = {
    'File': ['Folder','Document',],
    'Image': ['Image'],
    'Media': ['Video','Sound'],
    'Document': ['Document'],
    'Flash': ['Flash_App', 'Flash_Movie'],
    'Video': ['Video', 'Flash_Movie',],
    'Audio': ['Audio'],
    # for TinyMCE we also have to define lower-case items
    'image': ['Image'],
    'file': ['Folder','Image','Document',],
}

FILEBROWSER_VERSIONS = {
    'fb_thumb': {'verbose_name': ugettext('Admin Thumbnail'),
                 'width': 60, 'height': 60, 'opts': 'crop upscale'},
    'thumbnail': {'verbose_name': ugettext('Thumbnail (100px height)'),
                  'width': '', 'height': 100, 'opts': ''},
    'small': {'verbose_name': ugettext('Small (300x300px)'),
              'width': 300, 'height': 300, 'opts': 'crop'},
    'medium': {'verbose_name': ugettext('Medium (460px width)'),
               'width': 460, 'height': '', 'opts': ''},
    'big': {'verbose_name': ugettext('Big (620px width)'),
            'width': 620, 'height': '', 'opts': ''},
    'cropped': {'verbose_name': ugettext('Cropped (60x60px)'),
                'width': 60, 'height': 60, 'opts': 'crop'},
    'croppedthumbnail': {'verbose_name': ugettext('Cropped Thumbnail (140x140px)'),
                         'width': 140, 'height': 140, 'opts': 'crop'},
    'slideshow': {'verbose_name': ugettext('Slideshow'),
                  'width': 300, 'height': 300, 'opts': 'crop'},
    'slideshow-background': {'verbose_name': ugettext('Slideshow'),
                  'width': 550, 'height': '', 'opts': 'crop'},
}

FILEBROWSER_MAX_UPLOAD_SIZE = 1024*1024*20 # 20MB

# django-registration settings
ACCOUNT_ACTIVATION_DAYS = 7

# profile settings
AUTH_PROFILE_MODULE = "user_profiles.UserProfile"

# admin-tools settings
ADMIN_TOOLS_INDEX_DASHBOARD = 'cyclope.dashboard.CustomIndexDashboard'
ADMIN_TOOLS_APP_INDEX_DASHBOARD = 'cyclope.dashboard.CustomAppIndexDashboard'
ADMIN_TOOLS_THEMING_CSS = 'cyclope/css/admin_tools_theming.css'

LOCALE_PATHS = (os.path.join(os.path.dirname(__file__), "locale_external"), )

# django-haystack settings
HAYSTACK_SITECONF = 'cyclope_project.search_sites'
HAYSTACK_SEARCH_ENGINE = 'whoosh'

# dbgettext options
#DBGETTEXT_PROJECT_OPTIONS = 'cyclope.dbgettext_options'
DBGETTEXT_SPLIT_SENTENCES = False
DBGETTEXT_INLINE_HTML_TAGS = ('b','i','u','em','strong',)

# rosetta settings
ROSETTA_MESSAGES_SOURCE_LANGUAGE_CODE = 'es'
#ROSETTA_MAIN_LANGUAGE = 'es'
ROSETTA_MESSAGES_PER_PAGE = 15
ROSETTA_EXCLUDED_APPLICATIONS = (
    'admin_tools',
    'tagging',
    'tagging_autocomplete',
    'autoslug',
    'mptt_tree_editor',
    'mptt',
    'captcha',
    'filebrowser',
    'south',
    'registration',
    'profiles',
    'haystack',
    'dbgettext',
    'rosetta',
    )

# martkitup settings
JQUERY_URL = "cyclope/js/reuse_django_jquery.js" # We dont want jquery to be included twice in the admin.
MARKITUP_SET = 'cyclope/markitup/sets/textile'
MARKITUP_FILTER = ('django.contrib.markup.templatetags.markup.textile', {})

# crispy forms settings
CRISPY_TEMPLATE_PACK = 'uni_form'


# compressor settings

COMPRESS_ENABLED = False

COMPRESS_PARSER = "compressor.parser.HtmlParser"

# PRECOMPILERS are emptied on cyclope.core.compressor context processor if
# COMPRESS_ENABLED is False or COMPRESS_DEBUG_TOGGLE is set
COMPRESS_PRECOMPILERS = (
    ('text/less', '/usr/bin/lesscpy  {infile}'),
)

COMPRESS_DEBUG_TOGGLE = 'nocompress'



#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
# Copyright 2010 Código Sur - Nuestra América Asoc. Civil / Fundación Pacificar.
# All rights reserved.
#
# This file is part of Cyclope.
#
# Cyclope is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Cyclope is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.


"""
apps.articles.models
--------------------
"""

from django.db import models
from django.utils.translation import ugettext_lazy as _
from django.contrib.auth.models import User
from django.contrib.contenttypes.models import ContentType
from django.contrib.contenttypes import generic

from autoslug.fields import AutoSlugField
from cyclope.core.collections.models import Collectible
from cyclope.models import BaseContent, Author, Source, Image
from cyclope.apps.medialibrary.models import Picture

YES_NO = (('YES', _('yes')), ('NO', _('no')),)

class Article(BaseContent, Collectible):
    pretitle = models.CharField(_('pre-title'), max_length=250, blank=True)
    summary = models.TextField(_('summary'), blank=True)
    text = models.TextField(_('text'))
    author = models.ForeignKey(Author, verbose_name=_('author'),
                               null=True, blank=True, on_delete=models.SET_NULL)
    source = models.ForeignKey(Source, verbose_name=_('source'),
                               blank=True, null=True)
    date = models.DateTimeField(_('date'), blank=True, null=True)

    class Meta:
        verbose_name = _('article')
        verbose_name_plural = _('articles')
        ordering = ('-creation_date', 'name')

# FIXME: this registrations should be done elsewhere
import cyclope.apps.abuse
cyclope.apps.abuse.register(Article)

from cyclope.apps.custom_comments.moderator import CustomCommentModerator, moderator
moderator.register(Article, CustomCommentModerator)

from ratings.handlers import ratings
from cyclope.core.ratings.forms import LikeDislikeVoteForm
ratings.register(Article, form_class=LikeDislikeVoteForm)



#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
# Copyright 2012 Código Sur Asoc. Civil
# All rights reserved.
#
# This file is part of Cyclope.
#
# Cyclope is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Cyclope is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

"""
core.perms.templatetags
-----------------------
"""

from django import template
from django.contrib.auth import load_backend 

register = template.Library()


class CategoryPerms(template.Node):
    """Returns a dictionary containing the categoty based permissions the current user has for the current object.
    
    Syntax::
        {% category_perms [object] as [var_name] %}
    Example::
        {% category_perms current_object as cat_perms %}
    """
    def __init__(self, obj_var, var_name):
        self.var_name = var_name
        self.obj_var = obj_var

    def render(self, context):
        obj = context[self.obj_var]
        user = context["user"]
        cat_perm_backend = load_backend('cyclope.core.perms.backends.CategoryPermBackend')
        context[self.var_name] = cat_perm_backend.get_all_permissions(user, obj)
        return ''

@register.tag('per_category_perms')
def do_category_perms(parser, token):
    bits = token.contents.split()
    if bits[-2] != 'as':
        raise template.TemplateSyntaxError, "Missing 'as' argument for '%s' tag" % bits[0]
    return CategoryPerms(bits[1], bits[-1])



#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
# Copyright 2012 Código Sur Asoc. Civil
# All rights reserved.
#
# This file is part of Cyclope.
#
# Cyclope is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Cyclope is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

"""
This app implements DynamicForms using django-forms-builder
"""

from django.utils.translation import ugettext_lazy as _

from models import DynamicForm
from forms_builder.forms.views import form_detail

from cyclope.core import frontend
from cyclope import views

class FormDetail(frontend.FrontendView):
    """Display a DynamicForm
    """
    name='form-detail'
    verbose_name=_('show a form')
    is_default = True
    is_instance_view = True
    is_region_view = False
    is_content_view = True

    def get_response(self, request, req_context, options, content_object):
        return form_detail(request, content_object.slug)

frontend.site.register_view(DynamicForm, FormDetail)



#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
# Copyright 2010-2012 Código Sur Asociación Civil
# All rights reserved.
#
# This file is part of Cyclope.
#
# Cyclope is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Cyclope is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.


from django.utils.translation import ugettext_lazy as _
from django.shortcuts import redirect
from django.template import loader

from cyclope.core import frontend
from cyclope import views

from models import Poll, Submission, Question
from forms import QuestionForm, CaptchaForm

class PollSubmission(frontend.FrontendView):
    """Show or process a Poll Submission form"""

    name = 'submission'
    verbose_name=_('Poll submission form')
    is_content_view = True
    is_region_view = True

    def get_response(self, request, req_context, options, content_object):
        forms = []
        poll = content_object
        questions = Question.objects.filter(poll=poll)
        for question in questions:
            form = QuestionForm(question, data=request.POST or None, prefix=question.pk)
            forms.append(form)
        captcha_form = CaptchaForm(data=request.POST or None)

        if all( (f.is_valid() for f in forms) ) and captcha_form.is_valid():
            posted_answers = []
            for f in forms:
                posted_answers.extend(f.get_answers())
            submission = Submission(poll=poll)
            submission.save()
            submission.answers = posted_answers
            submission.save()
            return redirect('/poll/%s' % poll.slug)


        else:
            t = loader.get_template("polls/poll_submission.html")
            req_context.update({'poll': poll, 'forms': forms,
                                'captcha_form': captcha_form})
            return t.render(req_context)

frontend.site.register_view(Poll, PollSubmission)


class PollDetail(frontend.FrontendView):
    """Detail view for Polls"""
    name = 'detail'
    verbose_name=_('detailed view of the selected Poll')
    is_default = True
    is_content_view = True

    def get_response(self, request, req_context, options, content_object):
        return views.object_detail(request, req_context, content_object)

frontend.site.register_view(Poll, PollDetail)




#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
# Copyright 2010-2012 Código Sur Sociedad Civil
# All rights reserved.
#
# This file is part of Cyclope.
#
# Cyclope is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Cyclope is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

import codecs
from setuptools import setup, find_packages

version = '0.2.1'


def read(filename):
    return unicode(codecs.open(filename, encoding='utf-8').read())


long_description = '\n\n'.join([read('README.rst'),
                                read('CONTRIBUTORS.rst'),
                                read('CHANGELOG.rst')])

setup(
    name='cyclope3',
    version=version,
    description="CMS for pythonistas who like to code instead of using a web UI for every task.",
    long_description=long_description,
    author='Nicolás Echániz & Santiago Hoerth',
    author_email='nicoechaniz@codigosur.org',
    maintainer='Santiago Piccinini',
    maintainer_email='spiccinini@codigosur.org',
    url='http://forja.codigosur.org/projects/cyclope/',
    license='GPL v3',
    platforms=['OS Independent'],
    classifiers=[
        "Development Status :: 4 - Beta",
        "Environment :: Web Environment",
        "Framework :: Django",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: GNU General Public License v3 (GPLv3)",
        "Operating System :: OS Independent",
        "Programming Language :: Python",
        "Programming Language :: Python :: 2.6",
        "Programming Language :: Python :: 2.7",
        "Topic :: Internet :: WWW/HTTP :: Dynamic Content",
        "Topic :: Software Development",
        "Topic :: Software Development :: Libraries :: Application Frameworks",
    ],

    # revision number is indicated in the dependency_links for packages
    # that are downloaded from source to ensure a tested revision is used.
    dependency_links=[
        'hg+http://bitbucket.org/diegom/django-contact-form#egg=django-contact-form-0.4a1',
        'hg+http://bitbucket.org/nicoechaniz/django-rosetta_temp#egg=django-rosetta-0.6.2-temp',
        'hg+http://bitbucket.org/san/django-jsonfield#egg=django-jsonfield-0.6.0-cyclope',
        'git+http://github.com/HonzaKral/django-threadedcomments.git@issue/39#egg=django-threadedcomments-0.9'
    ],

    install_requires=[
        'Django>=1.4,<1.5',
        'django-autoslug==1.4.1',
        'django-mptt==0.4.2', # 0.4 breaks compatibility
        'django-mptt-tree-editor>=0.1,<0.2',
        'PIL>=1.1.7', # in PIL we trust
        'django-simple-captcha==0.2.0',
        'django-filebrowser-nograpup>=3.0.3,<3.1',
        'South>=0.7,<0.8',
        'django-registration==0.8',
        'django-profiles==0.2',
        'django-admin-tools==0.4.1',
        'django-contact-form>=0.4a1', # installed from our clone
        'Whoosh>=2.4.1,<2.5',
        'django-haystack>=1.2.7,<1.3',
        'textile==2.1.4',
        'django-dbgettext>=0.1',
        'django-rosetta==0.6.2-temp', # installed from our clone
        'django-markitup==1.0',
        'django-jsonfield==0.6.0-cyclope', # installed from our clone
        'feedparser==5.1',
        'django-forms-builder>=0.7.5,<0.8',
        'django-threadedcomments==0.9',
        'django-crispy-forms>=1.2,<1.3',
        'django-compressor>=1.2,<1.3',
        'django-generic-ratings>=0.6,<0.7',
    ],

    scripts=['cyclope/bin/cyclopeproject','cyclope/bin/cyclopedemo'],

    packages=find_packages(),

    include_package_data=True,
    zip_safe=False,
)



#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
# Copyright 2010-2012 Código Sur Sociedad Civil.
# All rights reserved.
#
# This file is part of Cyclope.
#
# Cyclope is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Cyclope is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.


from django.contrib import admin
from django.contrib.contenttypes import generic

from cyclope.core.frontend import site
from cyclope.core.collections.admin import CollectibleAdmin
from cyclope.admin import BaseContentAdmin
from cyclope.apps.related_admin import GenericFKWidget, GenericModelForm
from cyclope.apps.related_admin import GenericModelChoiceField as GMCField

from models import Series, SeriesContent

def series_inline_factory(series_model):

    class SeriesContentForm(GenericModelForm):
        other_object = GMCField(label='object', widget=GenericFKWidget('other_type',
                                                       cts=series_model.get_content_models()))
        def __init__(self, *args, **kwargs):
            super(SeriesContentForm, self).__init__(*args, **kwargs)
            self.fields['other_type'].choices = series_model.get_content_types_choices()

        class Meta:
            model = SeriesContent
            fields = ('order', 'other_type', 'other_object')

    class SeriesContentInline(generic.GenericStackedInline):
        model = SeriesContent
        form = SeriesContentForm
        ct_field = 'self_type'
        ct_fk_field = 'self_id'
        extra = 0
    
    return [SeriesContentInline]


class SeriesAdmin(CollectibleAdmin, BaseContentAdmin):
    inlines = series_inline_factory(Series) + CollectibleAdmin.inlines + BaseContentAdmin.inlines
    list_display = ('name', 'creation_date') + CollectibleAdmin.list_display
    search_fields = ('name', 'description', )
    list_filter = CollectibleAdmin.list_filter + ('creation_date',)





#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
# Copyright 2010-2012 Código Sur Sociedad Civil.
# All rights reserved.
#
# This file is part of Cyclope.
#
# Cyclope is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Cyclope is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from django.db import models
from django.utils.translation import ugettext_lazy as _
from django.contrib.contenttypes.models import ContentType

from autoslug.fields import AutoSlugField
from filebrowser.fields import FileBrowseField

from cyclope.models import BaseContent, Author, Source
from cyclope.core.collections.models import Collectible
from cyclope.utils import ThumbnailMixin
import cyclope.apps.abuse

class BaseMedia(BaseContent, Collectible, ThumbnailMixin):
    """Abstract class for media content.
    """
    author = models.ForeignKey(Author, verbose_name=_('author'),
                               null=True, blank=True, on_delete=models.SET_NULL)
    source = models.ForeignKey(Source, verbose_name=_('source'),
                               blank=True, null=True, on_delete=models.SET_NULL)
    description = models.TextField(_('description'), blank=True)

    media_file_field = None # This must me set to the media_file on the model
                            # (eg: audio for Soundtrack)
    @property
    def media_file(self):
        return getattr(self, self.media_file_field)

    class Meta:
        abstract = True
        ordering = ('-creation_date', 'name')


class Picture(BaseMedia):
    """Picture model.
    """

    image =  FileBrowseField(_('image'), max_length=100, format='Image',
                             directory='images/pictures/')
    media_file_field = "image"

    class Meta:
        verbose_name = _('picture')
        verbose_name_plural = _('pictures')


class SoundTrack(BaseMedia):
    """AudioTrack model.
    """
    audio =  FileBrowseField(_('audio'), max_length=250, format='Audio',
                             directory='sound_tracks/')
    image =  FileBrowseField(_('image'), max_length=100, format='Image',
                             directory='images/medialibrary/', blank=True,
                             null=True)
    media_file_field = "audio"

    class Meta:
        verbose_name = _('sound track')
        verbose_name_plural = _('sound tracks')


class MovieClip(BaseMedia):
    """MovieClip model.
    """
    still = FileBrowseField(_('still'), max_length=100, format='Image',
                            directory='images/medialibrary/', blank=True)
    video =  FileBrowseField(_('video'), max_length=100, format='Video',
                             directory='movie_clips/')
    media_file_field = "video"

    def image(self):
        return self.still

    def get_thumbnail_src(self):
        return self.still.url_thumbnail

    class Meta:
        verbose_name = _('movie clip')
        verbose_name_plural = _('movie clips')


class Document(BaseMedia):
    """Document model.
    """
    image = FileBrowseField(_('image'), max_length=100, format='Image',
                            directory='images/medialibrary/', blank=True)
    document =  FileBrowseField(_('document'), max_length=100, format='Document',
                            directory='documents/')
    media_file_field = "document"

    class Meta:
        verbose_name = _('document')
        verbose_name_plural = _('documents')


class FlashMovie(BaseMedia):
    """FlashMovie model.
    """
    image = FileBrowseField(_('image'), max_length=100, format='Image',
                            directory='images/medialibrary/', blank=True)
    flash =  FileBrowseField(_('flash'), max_length=100, format='Flash',
                                  directory='flashmovies/', blank=True)
    media_file_field = "flash"

    class Meta:
        verbose_name = _('flash movie')
        verbose_name_plural = _('flash movies')


class RegularFile(BaseMedia):
    """RegularFile model. Accepts any type of file.
    """
    image = FileBrowseField(_('image'), max_length=100, format='Image',
                            directory='images/medialibrary/', blank=True)
    file =  FileBrowseField(_('file'), max_length=100,
                            directory='regular_files/')
    media_file_field = "file"

    class Meta:
        verbose_name = _('file')
        verbose_name_plural = _('files')


class ExternalContent(BaseMedia):
    """ExternalContent. For media that's displayed with custom html.
    """
    image = FileBrowseField(_('image'), max_length=100, format='Image',
                            directory='images/medialibrary/', blank=True)
    content_url = models.CharField(_('content url'), max_length=100)
    new_window = models.BooleanField(_('open in new window'), default=False)
    skip_detail = models.BooleanField(_('skip detailed view'), default=False)
    media_file_field = "content_url"

    class Meta:
        verbose_name = _('external content')
        verbose_name_plural = _('external contents')

from cyclope.apps.custom_comments.moderator import CustomCommentModerator, moderator
from ratings.handlers import ratings
from cyclope.core.ratings.forms import LikeDislikeVoteForm

# register models on abuse registry
for key, val in locals().copy().iteritems():
    if isinstance(val, type) and issubclass(val, BaseMedia):
        cyclope.apps.abuse.register(val)
        moderator.register(val, CustomCommentModerator)
        ratings.register(val, form_class=LikeDislikeVoteForm)



#!/usr/bin/env python
# -*- coding: UTF-8 -*-
#
# Copyright 2010-2012 Código Sur Sociedad Civil
# All rights reserved.
#
# This file is part of Cyclope.
#
# Cyclope is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Cyclope is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

"""
templatetags.cyclope_utils
-------------------

General utility helper tags.
"""

try:
    import ipdb as pdb
except ImportError:
    import pdb

from django import template
from django.utils.safestring import mark_safe
from django.contrib.markup.templatetags import markup

import cyclope.settings as cyc_settings
from cyclope.utils import nohang
from cyclope.utils.lru_cache import LRULimitedSizeDict


MARKUP_RENDERER_WAIT = 5
MARKUP_CACHE_SIZE = 250

register = template.Library()

class JoinedStrings(template.Node):
    """Join a list of strings and put the result in the given template variable.

    The list can be of strings or template variables holding string values.
    """
    def __init__(self, element_list, var_name):
        self.data = []
        for element in element_list:
            if element[0] not in ['"', "'"]:
                self.data.append(template.Variable(element))
            else:
                self.data.append(element[1:-1])
        self.var_name = var_name

    def render(self, context):
        strings = []
        for item in self.data:
            if isinstance(item, template.Variable):
                strings.append(item.resolve(context))
            else:
                strings.append(item)

        context[self.var_name] = "".join(strings)
        return ''

@register.tag('join')
def do_join(parser, token):
    bits = token.contents.split()
    if bits[-2] != 'as':
        raise template.TemplateSyntaxError, "Missing 'as' argument for '%s' tag" % bits[0]
    return JoinedStrings(bits[1:-2], bits[-1])


class Alias(template.Node):
    def __init__(self, origin, alias):
        self.value = template.Variable(origin)

        if alias[0] not in ['"', "'"]:
            self.alias = template.Variable(alias)
        else:
            self.alias = alias[1:-1]

    def render(self, context):
        if isinstance(self.alias, template.Variable):
            context[unicode(self.alias.resolve(context))] = self.value.resolve(context)
        else:
            context[self.alias] = self.value.resolve(context)
        return ''

@register.tag('alias')
def do_alias(parser, token):
    bits = token.contents.split()
    if len(bits) != 4:
        raise template.TemplateSyntaxError, "'%s' tag takes exactly four arguments" % bits[0]
    if bits[-2] != 'as':
        raise template.TemplateSyntaxError, "Missing 'as' argument for '%s' tag" % bits[0]
    return Alias(bits[1], bits[3])


# code from http://djangosnippets.org/snippets/539/
class AssignNode(template.Node):
    def __init__(self, name, value):
        self.name = name
        self.value = value

    def render(self, context):
        context[self.name] = self.value.resolve(context, True)
        return ''

@register.tag('assign')
def do_assign(parser, token):
    """
    Assign an expression to a variable in the current context.

    Syntax::
        {% assign [name] [value] %}
    Example::
        {% assign list entry.get_related %}

    """
    bits = token.contents.split()
    if len(bits) != 3:
        raise template.TemplateSyntaxError("'%s' tag takes two arguments" % bits[0])
    value = parser.compile_filter(bits[2])
    return AssignNode(bits[1], value)

# based on http://djangosnippets.org/snippets/1627/
class AppendGetNode(template.Node):
    """
    Append paramaters to a GET querystring
    """
    def __init__(self, extra_context=None):
        self.extra_context = extra_context or {}

    def render(self, context):
        get = context['request'].GET.copy()
        for key, val in self.extra_context.iteritems():
            get[key] = val.resolve(context)

        get_encoded = ""
        if len(get):
            get_encoded = "%s" % get.urlencode()
        return get_encoded

@register.tag('append_to_get')
def do_append_to_get(parser, token):
    from django.template.base import token_kwargs
    kwargs = token_kwargs(token.split_contents()[1:], parser)
    return AppendGetNode(kwargs)


def admin_list_filter_without_all(cl, spec):
    choices = list(spec.choices(cl))
    choices.pop(0) # Remove "all" option
    return {'title': spec.title, 'choices' : choices}
admin_list_filter_without_all = register.inclusion_tag('admin/filter.html')(admin_list_filter_without_all)


lru_cache = LRULimitedSizeDict(size_limit=MARKUP_CACHE_SIZE)

@register.filter
def smart_style(value):
    value_hash = hash(value)
    result = lru_cache.get(value_hash, None)
    if result is not None:
        return result

    style = cyc_settings.CYCLOPE_TEXT_STYLE
    styles = {"wysiwyg": mark_safe,
              "markdown": markup.markdown,
              "textile": markup.textile,
              "raw": mark_safe}
    renderer = styles.get(style, None)
    if renderer is None:
        raise ValueError("Bad TEXT_STYLE option: %s" % style)
    else:
        result, success = nohang.run(renderer, args=(value,), wait=MARKUP_RENDERER_WAIT)
        if not success:
            result = value
        lru_cache[value_hash] = result
        return result

smart_style.is_safe = True


class PdbNode(template.Node):
    def render(self, context):
        # Access vars at the prompt for an easy reference to
        # variables in the context
        vars = []
        for dict in context.dicts:
            for k, v in dict.items():
                vars.append(k)
                locals()[k] = v
        pdb.set_trace()
        # You may access all context variables directly (they are stored in locals())
        return ''

@register.tag("pdb_debug")
def pdbdebug_tag(parser, token):
    """Tag that inspects template context.

    Usage:
    {% pdb_debug %}

    You can then access your context variables directly at the prompt.

    The vars variable additonally has a reference list of keys
    in the context.
    """
    return PdbNode()


@register.filter
def inline_template(obj, inline_view_name):
    """
    Returns the name of the requested inline template for the object obj.

    Eg: {{ article|inline_template:"teaser" }} -> "articles/article_teaser.html"
    """
    return "%s/%s_%s.html" % (obj.get_app_label(), obj.get_object_name(),
                              inline_view_name)



#!/usr/bin/env python

from django.conf.urls import patterns, include, url
import haystack # This is here preventing a circular import
from cyclope import settings as cyc_settings
from cyclope.core import frontend
frontend.autodiscover()

from django.contrib import admin
admin.autodiscover()

handler500 = 'cyclope.views.error_500'
handler404 = 'cyclope.views.error_404'

urlpatterns = patterns('',
    (r'', include('cyclope.default_urls')),
    (r'^%s' % cyc_settings.CYCLOPE_PREFIX,
     include(frontend.site.get_urls())),
)



#!/usr/bin/env python
# -*- coding: UTF-8 -*-
#
# Copyright 2010 Código Sur - Nuestra América Asoc. Civil / Fundación Pacificar.
# All rights reserved.
#
# This file is part of Cyclope.
#
# Cyclope is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Cyclope is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

import datetime
from south.db import db
from south.v2 import SchemaMigration
from django.db import models

class Migration(SchemaMigration):

    def forwards(self, orm):

        # Changing field 'ArticleImageData.label'
        db.alter_column('articles_articleimagedata', 'label', self.gf('django.db.models.fields.CharField')(max_length=250))


    def backwards(self, orm):

        # Changing field 'ArticleImageData.label'
        db.alter_column('articles_articleimagedata', 'label', self.gf('django.db.models.fields.CharField')(max_length=250, blank=True))


    models = {
        'articles.article': {
            'Meta': {'object_name': 'Article'},
            'allow_comments': ('django.db.models.fields.CharField', [], {'default': "'SITE'", 'max_length': '4'}),
            'author': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['cyclope.Author']"}),
            'creation_date': ('django.db.models.fields.DateTimeField', [], {'auto_now_add': 'True', 'blank': 'True'}),
            'date': ('django.db.models.fields.DateTimeField', [], {'null': 'True', 'blank': 'True'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'images': ('django.db.models.fields.related.ManyToManyField', [], {'symmetrical': 'False', 'to': "orm['cyclope.Image']", 'null': 'True', 'through': "orm['articles.ArticleImageData']", 'blank': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '250', 'db_index': 'True'}),
            'pictures': ('django.db.models.fields.related.ManyToManyField', [], {'symmetrical': 'False', 'to': "orm['medialibrary.Picture']", 'null': 'True', 'blank': 'True'}),
            'pretitle': ('django.db.models.fields.CharField', [], {'max_length': '250', 'blank': 'True'}),
            'published': ('django.db.models.fields.BooleanField', [], {'default': 'True', 'blank': 'True'}),
            'slug': ('autoslug.fields.AutoSlugField', [], {'unique': 'True', 'max_length': '50', 'populate_from': 'None', 'unique_with': '()', 'db_index': 'True'}),
            'source': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['cyclope.Source']", 'null': 'True', 'blank': 'True'}),
            'summary': ('django.db.models.fields.TextField', [], {'blank': 'True'}),

            'text': ('django.db.models.fields.TextField', [], {})
        },
        'articles.articleimagedata': {
            'Meta': {'object_name': 'ArticleImageData'},
            'article': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['articles.Article']"}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'image': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['cyclope.Image']"}),
            'label': ('django.db.models.fields.CharField', [], {'max_length': '250'})
        },
        'articles.attachment': {
            'Meta': {'object_name': 'Attachment'},
            'article': ('django.db.models.fields.related.ForeignKey', [], {'related_name': "u'attachments'", 'to': "orm['articles.Article']"}),
            'description': ('django.db.models.fields.CharField', [], {'db_index': 'True', 'max_length': '250', 'blank': 'True'}),
            'downloads': ('django.db.models.fields.IntegerField', [], {'default': '0', 'blank': 'True'}),
            'file': ('django.db.models.fields.files.FileField', [], {'max_length': '250', 'db_index': 'True'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'unique': 'True', 'max_length': '250', 'db_index': 'True'}),
            'slug': ('autoslug.fields.AutoSlugField', [], {'unique': 'True', 'max_length': '50', 'populate_from': 'None', 'unique_with': '()', 'db_index': 'True'})
        },
        'collections.category': {
            'Meta': {'unique_together': "(('collection', 'name'),)", 'object_name': 'Category'},
            'active': ('django.db.models.fields.BooleanField', [], {'default': 'True', 'db_index': 'True', 'blank': 'True'}),
            'collection': ('django.db.models.fields.related.ForeignKey', [], {'related_name': "u'collection categories'", 'to': "orm['collections.Collection']"}),
            'description': ('django.db.models.fields.TextField', [], {'null': 'True', 'blank': 'True'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'image': ('filebrowser.fields.FileBrowseField', [], {'max_length': '250', 'blank': 'True'}),
            'level': ('django.db.models.fields.PositiveIntegerField', [], {'db_index': 'True'}),
            'lft': ('django.db.models.fields.PositiveIntegerField', [], {'db_index': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '50'}),
            'parent': ('django.db.models.fields.related.ForeignKey', [], {'blank': 'True', 'related_name': "u'children'", 'null': 'True', 'to': "orm['collections.Category']"}),
            'rght': ('django.db.models.fields.PositiveIntegerField', [], {'db_index': 'True'}),
            'slug': ('autoslug.fields.AutoSlugField', [], {'unique_with': '()', 'max_length': '50', 'populate_from': 'None', 'db_index': 'True'}),
            'tree_id': ('django.db.models.fields.PositiveIntegerField', [], {'db_index': 'True'})
        },
        'collections.categorymap': {
            'Meta': {'object_name': 'CategoryMap'},
            'category': ('django.db.models.fields.related.ForeignKey', [], {'related_name': "'category_maps'", 'to': "orm['collections.Category']"}),
            'content_type': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['contenttypes.ContentType']"}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'object_id': ('django.db.models.fields.PositiveIntegerField', [], {'db_index': 'True'})
        },
        'collections.collection': {
            'Meta': {'object_name': 'Collection'},
            'content_types': ('django.db.models.fields.related.ManyToManyField', [], {'to': "orm['contenttypes.ContentType']", 'db_index': 'True', 'symmetrical': 'False'}),
            'description': ('django.db.models.fields.TextField', [], {'null': 'True', 'blank': 'True'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'image': ('filebrowser.fields.FileBrowseField', [], {'max_length': '250', 'blank': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'unique': 'True', 'max_length': '50'}),
            'navigation_root': ('django.db.models.fields.BooleanField', [], {'default': 'False', 'blank': 'True'}),
            'slug': ('autoslug.fields.AutoSlugField', [], {'unique_with': '()', 'max_length': '50', 'populate_from': 'None', 'db_index': 'True'}),
            'visible': ('django.db.models.fields.BooleanField', [], {'default': 'True', 'blank': 'True'})
        },
        'contenttypes.contenttype': {
            'Meta': {'unique_together': "(('app_label', 'model'),)", 'object_name': 'ContentType', 'db_table': "'django_content_type'"},
            'app_label': ('django.db.models.fields.CharField', [], {'max_length': '100'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'model': ('django.db.models.fields.CharField', [], {'max_length': '100'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '100'})
        },
        'cyclope.author': {
            'Meta': {'object_name': 'Author'},
            'content_types': ('django.db.models.fields.related.ManyToManyField', [], {'to': "orm['contenttypes.ContentType']", 'db_index': 'True', 'symmetrical': 'False'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'image': ('filebrowser.fields.FileBrowseField', [], {'default': "''", 'max_length': '100', 'blank': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '250', 'db_index': 'True'}),
            'notes': ('django.db.models.fields.TextField', [], {'default': "''", 'blank': 'True'}),
            'origin': ('django.db.models.fields.CharField', [], {'default': "''", 'max_length': '250', 'db_index': 'True', 'blank': 'True'}),
            'slug': ('autoslug.fields.AutoSlugField', [], {'unique': 'True', 'max_length': '50', 'populate_from': 'None', 'unique_with': '()', 'db_index': 'True'})
        },
        'cyclope.image': {
            'Meta': {'object_name': 'Image'},
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'image': ('filebrowser.fields.FileBrowseField', [], {'max_length': '100'})
        },
        'cyclope.source': {
            'Meta': {'object_name': 'Source'},
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'link': ('django.db.models.fields.CharField', [], {'default': "''", 'max_length': '250', 'blank': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'unique': 'True', 'max_length': '250', 'db_index': 'True'}),
            'slug': ('autoslug.fields.AutoSlugField', [], {'unique': 'True', 'max_length': '50', 'populate_from': 'None', 'unique_with': '()', 'db_index': 'True'})
        },
        'medialibrary.picture': {
            'Meta': {'object_name': 'Picture'},
            'author': ('django.db.models.fields.CharField', [], {'db_index': 'True', 'max_length': '100', 'blank': 'True'}),
            'description': ('django.db.models.fields.TextField', [], {'blank': 'True'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'image': ('filebrowser.fields.FileBrowseField', [], {'max_length': '100'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '250', 'db_index': 'True'}),
            'published': ('django.db.models.fields.BooleanField', [], {'default': 'True', 'blank': 'True'}),
            'slug': ('autoslug.fields.AutoSlugField', [], {'unique': 'True', 'max_length': '50', 'populate_from': 'None', 'unique_with': '()', 'db_index': 'True'}),

        }
    }

    complete_apps = ['articles']



#!/usr/bin/env python
# -*- coding: UTF-8 -*-
#
# Copyright 2010 Código Sur - Nuestra América Asoc. Civil / Fundación Pacificar.
# All rights reserved.
#
# This file is part of Cyclope.
#
# Cyclope is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Cyclope is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from django.conf import settings
from cyclope import settings as cyc_settings

def site_settings(request):
    """Exposes all the settings in cyclope.settings to the template.
    """
    settings_dict = {}
    for setting in dir(cyc_settings):
        if setting == setting.upper() and setting.startswith('CYCLOPE'):
            settings_dict[setting] = getattr(cyc_settings, setting)
    return settings_dict


def compressor(request):
    """Exposes COMPRESS_ENABLED setting.
    """
    settings_dict = {}

    compress_enabled = settings.COMPRESS_ENABLED
    if settings.COMPRESS_DEBUG_TOGGLE and settings.COMPRESS_DEBUG_TOGGLE in request.GET:
        compress_enabled = False

    if not compress_enabled:
        settings.COMPRESS_PRECOMPILERS = tuple()
    settings_dict["COMPRESS_ENABLED"] = compress_enabled
    return settings_dict



from django import template
from django.core.urlresolvers import reverse
from django.contrib.contenttypes.models import ContentType

register = template.Library()

@register.filter
def abuse_report_link(value):
    ct_id = ContentType.objects.get_for_model(value).pk
    obj_id = value.pk
    return reverse("abuse-report", args=(ct_id, obj_id))



#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
# Copyright 2010 Código Sur - Nuestra América Asoc. Civil / Fundación Pacificar.
# All rights reserved.
#
# This file is part of Cyclope.
#
# Cyclope is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Cyclope is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from django.contrib import admin
from django import forms

from django.utils.translation import ugettext_lazy as _
from django.contrib.contenttypes.models import ContentType
from django.contrib.admin.widgets import AdminTextareaWidget
from markitup.widgets import AdminMarkItUpWidget

from cyclope.core.collections.admin import CollectibleAdmin
from cyclope.admin import BaseContentAdmin
from cyclope.widgets import CKEditor
from cyclope.models import MenuItem
from cyclope import settings as cyc_settings
from cyclope.core import frontend
from models import StaticPage, HTMLBlock


class StaticPageAdminForm(forms.ModelForm):
    menu_items = forms.ModelMultipleChoiceField(label=_('Menu items'),
                    queryset = MenuItem.tree.all(), required=False,
                    )
    def __init__(self, *args, **kwargs):
    # this was initially written to be used for any BaseContent, that's
    # why we don't assume the content_type to be pre-determined
    # TODO(nicoechaniz): update code
        super(forms.ModelForm, self).__init__(*args, **kwargs)
        if self.instance.id is not None:
            instance_type = ContentType.objects.get_for_model(self.instance)
            selected_items = [
                values[0] for values in
                MenuItem.objects.filter(
                    content_type=instance_type,
                    object_id=self.instance.id).values_list('id') ]
            self.fields['menu_items'].initial = selected_items

    class Meta:
        model = StaticPage


class StaticPageAdmin(CollectibleAdmin, BaseContentAdmin):
    # updates related menu_items information when a StaticPaget is saved
    form = StaticPageAdminForm
    list_display = ('__unicode__', ) + CollectibleAdmin.list_display
    search_fields = ('name', 'text', )
    fieldsets = ((None,
                  {'fields': ('name', 'text',)}),
                 (_('Publication data'),
                  {
                    'classes': ('collapse',),
                    'fields': ('published', 'summary', 'menu_items')}),
                 )
    inlines = CollectibleAdmin.inlines + BaseContentAdmin.inlines

    def save_model(self, request, obj, form, change):
        super(CollectibleAdmin, self).save_model(request, obj, form, change)
        object_type = ContentType.objects.get_for_model(obj)
        selected_items_ids = form.data.getlist('menu_items')
        selected_items = set(MenuItem.objects.filter(pk__in=selected_items_ids))
        old_items = set(MenuItem.objects.filter(content_type=object_type,
                                                object_id=obj.id))
        discarded_items = old_items.difference(selected_items)
        new_items = selected_items.difference(old_items)
        for menu_item in discarded_items:
            menu_item.content_type = None
            menu_item.object_id = None
            menu_item.content_view = None
            menu_item.save()
        for menu_item in new_items:
            menu_item.content_type = object_type
            menu_item.content_view = frontend.site.get_default_view_name(StaticPage)
            menu_item.object_id = obj.id
            menu_item.save()

admin.site.register(StaticPage, StaticPageAdmin)


class HTMLBlockAdminForm(forms.ModelForm):
    def __init__(self, *args, **kwargs):
        super(HTMLBlockAdminForm, self).__init__(*args, **kwargs)
        self.fields['text'].widget = AdminTextareaWidget()


class HTMLBlockAdmin(admin.ModelAdmin):
    form = HTMLBlockAdminForm
    search_fields = ('name', 'text', )

admin.site.register(HTMLBlock, HTMLBlockAdmin)




# encoding: utf-8
import datetime
from south.db import db
from south.v2 import SchemaMigration
from django.db import models

class Migration(SchemaMigration):

    def forwards(self, orm):
        
        # Adding model 'Country'
        db.create_table('locations_country', (
            ('id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('name', self.gf('django.db.models.fields.CharField')(max_length=255)),
        ))
        db.send_create_signal('locations', ['Country'])

        # Adding model 'Region'
        db.create_table('locations_region', (
            ('id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('country', self.gf('django.db.models.fields.related.ForeignKey')(to=orm['locations.Country'])),
            ('name', self.gf('django.db.models.fields.CharField')(max_length=255)),
        ))
        db.send_create_signal('locations', ['Region'])

        # Adding model 'City'
        db.create_table('locations_city', (
            ('id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('region', self.gf('django.db.models.fields.related.ForeignKey')(to=orm['locations.Region'])),
            ('name', self.gf('django.db.models.fields.CharField')(max_length=255)),
        ))
        db.send_create_signal('locations', ['City'])


    def backwards(self, orm):
        
        # Deleting model 'Country'
        db.delete_table('locations_country')

        # Deleting model 'Region'
        db.delete_table('locations_region')

        # Deleting model 'City'
        db.delete_table('locations_city')


    models = {
        'locations.city': {
            'Meta': {'object_name': 'City'},
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '255'}),
            'region': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['locations.Region']"})
        },
        'locations.country': {
            'Meta': {'object_name': 'Country'},
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '255'})
        },
        'locations.region': {
            'Meta': {'object_name': 'Region'},
            'country': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['locations.Country']"}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '255'})
        }
    }

    complete_apps = ['locations']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
# Copyright 2010 Código Sur - Nuestra América Asoc. Civil / Fundación Pacificar.
# All rights reserved.
#
# This file is part of Cyclope.
#
# Cyclope is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Cyclope is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from django import forms
from django.utils.translation import ugettext_lazy as _
from django.template import loader


from cyclope import views
from cyclope import settings as cyc_settings
from cyclope.core import frontend
from cyclope.utils import NamePaginator

from models import Contact


class ContactDetail(frontend.FrontendView):
    """Detail view for Contacts"""
    name='detail'
    verbose_name=_('detailed view of the selected Contact')
    is_default = True
    is_instance_view = True
    is_content_view = True

    def get_response(self, request, req_context, options, content_object):
        return views.object_detail(request, req_context, content_object)

frontend.site.register_view(Contact, ContactDetail)

class TeaserListOptions(forms.Form):
    items_per_page = forms.IntegerField(label=_('Items per page'), initial=3, min_value=1)
    order_by = forms.ChoiceField(label=_('Order by'),
                                 choices=(('given_name', _('given name')),
                                          ('surname', _('surname'))),
                                 initial='given_name')

class ContactTeaserList(frontend.FrontendView):
    """Teaser list view for Contacts.
    """
    name='teaser_list'
    verbose_name=_('list of Contact teasers')
    is_instance_view = False
    is_content_view = True
    is_region_view = True

    options_form = TeaserListOptions
    template = "contacts/contact_teaser_list.html"

    def get_response(self, request, req_context, options):
        contacts = Contact.objects.all()
        # Surname is optional, but Paginator needs the value if ordering for surname
        # so we cheat adding a temporary surname.
        for contact in contacts:
            if not contact.surname:
                contact.surname = "Aa fake name"
        paginator = NamePaginator(contacts, on=options["order_by"],
                                  per_page=options["items_per_page"])

        for contact in contacts:
            if contact.surname == "Aa fake name":
                contact.surname = ""

        # Make sure page request is an int. If not, deliver first page.
        try:
            page_number = int(request.GET.get('page', '1'))
        except ValueError:
            page_number = 1

        # DjangoDocs uses page differently
        # If page request (9999) is out of range, deliver last page of results.
        try:
            page = paginator.page(page_number)
        except (EmptyPage, InvalidPage):
            page = paginator.page(paginator.num_pages)

        req_context.update({'contacts': page.object_list,
                            'page': page,
                            'view_options': options})
        t = loader.get_template(self.template)
        return t.render(req_context)

frontend.site.register_view(Contact, ContactTeaserList)



#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
# Copyright 2010 Código Sur - Nuestra América Asoc. Civil / Fundación Pacificar.
# All rights reserved.
#
# This file is part of Cyclope.
#
# Cyclope is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Cyclope is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

"""
templatetags.layout
-------------------

Template tags to mark regions in a template, which enable the configuration
of different Layouts.
"""

from django import template
from cyclope.utils import layout_for_request, get_or_set_cache
from cyclope.core import frontend

register = template.Library()

@register.inclusion_tag('cyclope/region.html', takes_context=True)
def region(context, region_name):
    """Defines a region where views can be inserted in a template.

    The views that will actualy be inserted are defined in a Layout.

    Usage::

        {% region 'region_name' %}

    The region name must be one of the regions available to the template
    according to the theme configuration (as defined in the theme's __init__ file)

    """

    # if we have a layout in the context use that one, otherwise guess it from the request
    layout = context.get('layout', layout_for_request(context['request']))
    region_vars = {'layout_name': layout.slug, 'region_name': region_name}

    regionviews = layout.regionview_set.filter(
        region=region_name).order_by('weight')
    views = []


    for regionview in regionviews:
        view_vars={}
        view = frontend.site.get_view(
            regionview.content_type.model_class(),
            regionview.content_view,
            )
        # instance views need instance data -> slug
        if view.is_instance_view:
            if regionview.content_object is None:
                raise template.TemplateSyntaxError
            slug = regionview.content_object.slug
            view_vars['output'] = view(context['request'], region_name=region_name,
                                       content_object=regionview.content_object,
                                       view_options=regionview.view_options)
            view_vars['slug'] = slug
        else:
            view_vars['output'] = view(context['request'], region_name=region_name,
                                       view_options=regionview.view_options)
        view_vars['name'] = regionview.content_view
        view_vars['model'] = regionview.content_type.model
        views.append(view_vars)

    region_vars['views'] = views

    return region_vars



#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
# Copyright 2010-2012 Código Sur Sociedad Civil.
# All rights reserved.
#
# This file is part of Cyclope.
#
# Cyclope is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Cyclope is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.


from django.contrib import admin
from django import forms

from cyclope.core.collections.admin import CollectibleAdmin
from cyclope.admin import BaseContentAdmin

from models import *

class MediaAdmin(CollectibleAdmin, BaseContentAdmin):
    inlines = CollectibleAdmin.inlines + BaseContentAdmin.inlines
    search_fields = ('name', 'description', )
    list_filter = CollectibleAdmin.list_filter + ('creation_date',)

has_thumbnail = [Picture, MovieClip, FlashMovie]
def media_admin_factory(media_model):
    class MediaLibraryForm(forms.ModelForm):
        def __init__(self, *args, **kwargs):
            super(MediaLibraryForm, self).__init__(*args, **kwargs)
            author_choices = [('', '------')]
            for author in Author.objects.all():
                if media_model in [ctype.model_class()
                                   for ctype in author.content_types.all()]:
                    author_choices.append((author.id, author.name))
            self.fields['author'].choices = author_choices

        class Meta:
            model = media_model
            

    if media_model in has_thumbnail:
        list_display = ['name', 'thumbnail']
    else:
        list_display = ['name']
    list_display += CollectibleAdmin.list_display

    return type('%sAdmin' % media_model.__name__,
                (MediaAdmin,),
                {'form': MediaLibraryForm, 'list_display': list_display})

admin.site.register(Picture, media_admin_factory(Picture))
admin.site.register(SoundTrack, media_admin_factory(SoundTrack))
admin.site.register(MovieClip, media_admin_factory(MovieClip))
admin.site.register(Document, media_admin_factory(Document))
admin.site.register(FlashMovie, media_admin_factory(FlashMovie))
admin.site.register(RegularFile, media_admin_factory(RegularFile))
admin.site.register(ExternalContent, media_admin_factory(ExternalContent))



#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
# Copyright 2010-2012 Código Sur Sociedad Civil.
# All rights reserved.
#
# This file is part of Cyclope.
#
# Cyclope is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Cyclope is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

"""
forms
-----
"""

from django import forms
from django.utils.translation import ugettext_lazy as _
from django.core.exceptions import ValidationError
from django.contrib.admin.widgets import AdminTextareaWidget

from mptt.forms import TreeNodeChoiceField

from cyclope.core.frontend import site
from cyclope.models import MenuItem, RelatedContent, SiteSettings, Layout, \
                            RegionView
from cyclope.fields import MultipleField
from cyclope.themes import get_all_themes, get_theme
from cyclope.apps.related_admin import GenericFKWidget, GenericModelForm
from cyclope.apps.related_admin import GenericModelChoiceField as GMCField



class AjaxChoiceField(forms.ChoiceField):
    """ChoiceField that always returns true for validate().
    """
    # we always return true because we don't know what choices were available
    # at submit time, because they were populated through AJAX.
    # we use this in cases where providing all the posible choices at init time
    # would be too expensive
    #TODO(nicoechaniz): generate valid choices at init time to avoid this hack when possible?
    def validate(self, value):
        return True


class RelatedContentForm(GenericModelForm):

    other_object = GMCField(label='object', widget=GenericFKWidget('other_type',
                                                   cts=site.base_content_types))

    def __init__(self, *args, **kwargs):
        super(RelatedContentForm, self).__init__(*args, **kwargs)
        self.fields['other_type'].choices = site.get_base_ctype_choices()

    class Meta:
        model = RelatedContent
        fields = ('order', 'other_type', 'other_object')


class ViewOptionsFormMixin(object):
    options_field_name = 'view_options'
    view_field_name = 'content_view'
    field_names = []
    model = None

    def set_initial_view_options(self, obj, model):
        view_name = getattr(obj, self.view_field_name)
        view = site.get_view(model, view_name)

        self.fields[self.options_field_name] = MultipleField(form=view.options_form,
                                                             required=False)

        initial_options = self.fields[self.options_field_name].initial
        actual_options = getattr(obj, self.options_field_name)
        self.initial[self.options_field_name] = actual_options or initial_options

    def get_view(self, values):
        return site.get_view(self.model, values[self.view_field_name])

    def clean_view_options(self):
        # Retrieve content_view and content_type of current data
        values = {}
        field_names = self.field_names
        for name in field_names:
            field, widget = self.fields[name], self.fields[name].widget
            values[name] = widget.value_from_datadict(self.data, None,
                                                      self.add_prefix(name))
            values[name] = field.clean(values[name])
        cleaned_value = {}
        if all(values.values()):
            view = self.get_view(values)
            # Now we need to instance view_options field with the viw of the current
            # form, and clean it.
            self.fields[self.options_field_name] = MultipleField(form=view.options_form,
                                                        required=False)
            field = self.fields[self.options_field_name]
            value = field.widget.value_from_datadict(self.data, None,
                                                     self.add_prefix(self.options_field_name))

            cleaned_value = field.clean(value, validate=True)
        return cleaned_value


class MenuItemAdminForm(GenericModelForm, ViewOptionsFormMixin):
    # content_view choices get populated through javascript
    # when a template is selected
    content_view = AjaxChoiceField(label=_('View'), required=False)
    content_object = GMCField(label=_('Content object'), required=False,
                              widget=GenericFKWidget("content_type",
                                                     cts=site._registry.keys()))
    parent = TreeNodeChoiceField(label=_('Parent'), queryset=MenuItem.tree.all(),
                                 required=False)
    view_options = MultipleField(label=_('View options'), form=None, required=False)


    field_names = ['content_type', "content_view"]

    def __init__(self, *args, **kwargs):
        super(MenuItemAdminForm, self).__init__(*args, **kwargs)
        if self.instance.id is not None:
            # chainedSelect will show the selected choice
            # if it is present before filling the choices through AJAX
            menu_item = MenuItem.objects.get(id=self.instance.id)
            selected_view = menu_item.content_view
            self.fields['content_view'].choices = [(selected_view,
                                                    selected_view)]
            if menu_item.content_type:
                model = menu_item.content_type.model_class()
                self.set_initial_view_options(menu_item, model)

        self.fields['content_type'].choices = site.get_registry_ctype_choices()

    def get_view(self, values):
        return site.get_view(values['content_type'].model_class(),
                              values[self.view_field_name])

    def clean(self):
        data = self.cleaned_data
        data['content_object'] = data.get('content_object')

        if data['custom_url'] and (data.get('content_type')
                                   or data.get('content_object')
                                   or data.get('content_view')):
            raise ValidationError(
                _(u'You can not set a Custom URL for menu entries \
                    with associated content'))

        else:
            if data['content_type']:
                if data['content_view'] == '' or not data['content_view']:
                    raise(ValidationError(
                        _(u'You need to select a content view')))
                else:
                    view = site.get_view(data['content_type'].model_class(),
                                         data['content_view'])
                    if view.is_instance_view and data['content_object'] is None:
                        raise(ValidationError(
                            _(u'The selected view requires a content object')))
                    elif not view.is_instance_view:
                        # if not an instance it does not need a content object
                        if data['content_object'] is not None:
                            data['content_object'] = None

        return super(MenuItemAdminForm, self).clean()

    class Meta:
        model = MenuItem


class SiteSettingsAdminForm(forms.ModelForm):
    theme = forms.ChoiceField(label=_('Theme'),
        choices=[(theme_name,  theme.verbose_name)
                 for theme_name, theme in get_all_themes().iteritems()],
        required=True)

    def __init__(self, *args, **kwargs):
        super(SiteSettingsAdminForm, self).__init__(*args, **kwargs)
        self.fields["keywords"].widget = AdminTextareaWidget()
        self.fields["description"].widget = AdminTextareaWidget()
        self.fields['rss_content_types'].choices = site.get_base_ctype_choices()

        #TODO(diegoM): I don't like this...
        if ('', '------') in self.fields['rss_content_types'].choices:
            self.fields['rss_content_types'].choices.remove(('', '------'))

    class Meta:
        model = SiteSettings


class LayoutAdminForm(forms.ModelForm):
    template = forms.ChoiceField(label=_('Template'), required=True)

    def __init__(self, *args, **kwargs):
        super(LayoutAdminForm, self).__init__(*args, **kwargs)

        try:
            theme_name = SiteSettings.objects.get().theme
        except:
            return

        theme = get_theme(theme_name)
        tpl_choices = [(tpl, tpl_settings['verbose_name'])
                       for tpl, tpl_settings
                       in theme.layout_templates.items()]

        self.fields['template'].choices = tpl_choices

    class Meta:
        model = Layout


class RegionViewInlineForm(forms.ModelForm, ViewOptionsFormMixin):

    # Choices for these fields get populated through javascript/JSON.
    region = AjaxChoiceField(label=_('Region'), required=False)
    content_view = AjaxChoiceField(label=_('View'), required=False)
    object_id = AjaxChoiceField(label=_('Content object'), required=False)
    view_options = MultipleField(label=_('View options'), form=None, required=False)

    field_names = ['content_type', "content_view"]

    def __init__(self, *args, **kwargs):
        super(RegionViewInlineForm, self).__init__(*args, **kwargs)
        if self.instance.id is not None:
            # chainedSelect.js will show the selected choice
            # if it is present before filling the choices through AJAX
            # so we set all choices here at __init__ time
            region_view = RegionView.objects.get(id=self.instance.id)

            if region_view.region:
                selected_region = region_view.region
                self.fields['region'].choices = [(selected_region,
                                                  selected_region)]
            if region_view.content_view:
                selected_view = region_view.content_view
                self.fields['content_view'].choices = [(selected_view,
                                                        selected_view)]
            if region_view.content_type:
                model = region_view.content_type.model_class()
                self.set_initial_view_options(region_view, model)

            if region_view.content_object:
                content_object = region_view.content_object
                self.fields['object_id'].choices = [(content_object.id,
                                                        content_object.name)]

        self.fields['content_type'].choices = site.get_registry_ctype_choices()

    def get_view(self, values):
        return site.get_view(values['content_type'].model_class(),
                              values[self.view_field_name])

    def clean(self):
        #TODO(nicoechaniz): this whole form validation could be simplified if we were not using our custom AjaxChoiceField and fields were actually marked as not null in the model definition. The problem is that the standard form validation will check for valid choices, so we should set choices to valid ones for each choicefield at form init time.

        data = self.cleaned_data
        if not data['DELETE']:
            if data['object_id'] == '':
                data['object_id'] = None

            if not data['content_type']:
                raise(ValidationError(_(u'Content type can not be empty')))

            else:
                if not data['region']:
                    raise(ValidationError(_(u'You need to select a region')))
                if data['content_view'] == '' or not data['content_view']:
                    raise(ValidationError(
                        _(u'You need to select a content view')))
                else:
                    view = site.get_view(data['content_type'].model_class(),
                                         data['content_view'])
                    if view.is_instance_view and data['object_id'] is None:
                        raise(ValidationError(
                            _(u'The selected view requires a content object')))
                    elif not view.is_instance_view:
                        # if not an instance it does not need a content object
                        if data['object_id'] is not None:
                            data['object_id'] = None

        return super(RegionViewInlineForm, self).clean()

    class Meta:
        model = RegionView


class AuthorAdminForm(forms.ModelForm):
    def __init__(self, *args, **kwargs):
        super(AuthorAdminForm, self).__init__(*args, **kwargs)
        self.fields['content_types'].choices = site.get_base_ctype_choices()


from registration.forms import RegistrationFormUniqueEmail
from captcha.fields import CaptchaField
from cyclope.utils import CrispyFormsSimpleMixin

class RegistrationFormWithCaptcha(RegistrationFormUniqueEmail,
                                    CrispyFormsSimpleMixin):
    captcha = CaptchaField(label=_("Security code"))



#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
# Copyright 2010-2012 Código Sur Sociedad Civil.
# All rights reserved.
#
# This file is part of Cyclope.
#
# Cyclope is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Cyclope is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

"""
To activate your index dashboard add the following to your settings.py::
    ADMIN_TOOLS_INDEX_DASHBOARD = 'cyclope_project.dashboard.CustomIndexDashboard'

And to activate the app index dashboard::
    ADMIN_TOOLS_APP_INDEX_DASHBOARD = 'cyclope_project.dashboard.CustomAppIndexDashboard'
"""

from django.utils.translation import ugettext_lazy as _
from django.core.urlresolvers import reverse
from django.conf import settings
from django.contrib.sites.models import Site

from admin_tools.dashboard import modules, Dashboard, AppIndexDashboard
from contact_form.models import ContactFormSettings

from cyclope.models import SiteSettings
from cyclope.utils import get_singleton

class ModuleNotFound(Exception):
    """Dashboard module not found in dashboard children"""
    def __init__(self, module_title):
        self.title = module_title

    def __str__(self):
        return "Module %s not found in dashboard children" % repr(self.title)

class CustomIndexDashboard(Dashboard):
    """
    Custom index dashboard for cyclope_project.
    """
    def __init__(self, **kwargs):
        Dashboard.__init__(self, **kwargs)
        self.title = _('Site Administration')
        self.columns = 1

    def init_with_context(self, context):
        """
        Use this method if you need to access the request context.
        """
        user = context.get('user')

        self.children.append(modules.Group(
            title=_('Content'),
            css_classes = ('dbmodule-content', 'main-area-modules',),
            display="tabs",
            draggable = False,
            deletable = False,
            collapsible= False,
            pre_content = _('Create, delete or modify content for your website'),
            children = (
                modules.ModelList(
                    title=_('Main'),
                    css_classes = ('dbmodule-content_main',),
                    include_list=[
                        'cyclope.apps.articles.models.Article',
                        'cyclope.apps.staticpages.models.StaticPage',
                        'cyclope.apps.staticpages.models.HTMLBlock',
                        ]),
                modules.ModelList(
                    title=_('Multimedia Library'),
                    css_classes = ('dbmodule-content_media_library',),
                    include_list=[
                        'cyclope.apps.medialibrary.models.Picture',
                        'cyclope.apps.medialibrary.models.MovieClip',
                        'cyclope.apps.medialibrary.models.SoundTrack',
                        'cyclope.apps.medialibrary.models.Document',
                        'cyclope.apps.medialibrary.models.RegularFile',
                        'cyclope.apps.medialibrary.models.FlashMovie',
                        'cyclope.apps.medialibrary.models.ExternalContent',
                        ]),
                modules.ModelList(
                    title=_('Authors and Sources'),
                    css_classes = ('dbmodule-content_authors_and_sources',),
                    include_list=[
                        'cyclope.models.Author',
                        'cyclope.models.Source',
                        ]),

                modules.ModelList(
                    title=_('Comments'),
                    css_classes = ('dbmodule-comments'),
                    #pre_content = _('Review and moderate user comments'),
                    include_list=[
                        'django.contrib.comments.models.Comment',
                    ]),
                )))

        self.children.append(modules.Group(
            title=_('Site structure'),
            css_classes = ('dbmodule-site_structure', 'main-area-modules',),
            pre_content = _('Modify your site layout and collections'),
            display="tabs",
            draggable = False,
            deletable = False,
            collapsible= False,
            children = (

                modules.ModelList(
                    title=_('Collections'),
                    css_classes = ('dbmodule-content_collection',),
                    include_list=[
                       'cyclope.core.collections.models.Collection',
                       'cyclope.core.collections.models.Category',
                        ]),
                modules.ModelList(
                    title=_('Menus'),
                    css_classes = ('dbmodule-menues',),
                    include_list=[
                        'cyclope.models.Menu',
                        'cyclope.models.MenuItem',
                        ]),
                modules.ModelList(
                    title=_('Layouts'),
                    css_classes = ('dbmodule-layout',),
                    include_list=[
                        'cyclope.models.Layout',
                        ]),
               )))


        site_settings = get_singleton(SiteSettings)
        contact_form = get_singleton(ContactFormSettings)

        if user.has_perm('cyclope.change_sitesettings'):
            self.children.append(modules.LinkList(
                    title=_('Global Settings'),
                    css_classes = ('dbmodules-global_settings', 'main-area-modules',),
                    draggable = False,
                    deletable = False,
                    collapsible= False,
                    children=[
                        {'title': _('Site Settings'),
                         'url': '/admin/cyclope/sitesettings/%s/' % site_settings.id,
                         },
                        {'title': _('Contact Form'),
                         'url': '/admin/contact_form/contactformsettings/%s/' % contact_form.id,
                         },
                        ]
                    ),)

        plugins_children = [
            modules.ModelList(
                title=_('Newsletter'),
                css_classes = ('dbmodule-newsletter',),
                include_list=[
                    'cyclope.apps.newsletter.models.Newsletter',
                    ]),
            modules.ModelList(
                title=_('Forms'),
                css_classes = ('dbmodule-forms',),
                include_list=[
                    'forms_builder.forms.models.Form',
                    ]),
            modules.ModelList(
                title=_('Polls'),
                css_classes = ('dbmodule-polls', 'main-area-modules',),
                include_list=[
                    'cyclope.apps.polls.models.Poll',
                    'cyclope.apps.polls.models.Question',
                    ]),
            modules.ModelList(
                title=_('Feeds'),
                css_classes = ('dbmodule-feeds',),
                include_list=[
                    'cyclope.apps.feeds.models.Feed',
                    ]),
            modules.ModelList(
                title=_('Contacts'),
                css_classes = ('dbmodule-contacts', 'main-area-modules',),
                include_list=[
                    'cyclope.apps.contacts.models.Contact',
                    ]),
            modules.ModelList(
                title=_('Abuse'),
                css_classes = ('dbmodule-abuse', 'main-area-modules',),
                include_list=[
                    'cyclope.apps.abuse.models.AbuseType',
                    'cyclope.apps.abuse.models.AbuseReport',
                    ]),
            ]

        self.children.append(modules.Group(
            title=_('Plugins'),
            css_classes = ('dbmodule-plugins', 'main-area-modules',),
            display="tabs",
            draggable = False,
            deletable = False,
            collapsible= False,
            pre_content = (''),
            children = plugins_children
            ))

        self.children.append(modules.Group(
            title=_('Advanced'),
            css_classes = ('dbmodule-advanced', 'main-area-modules',),
            display="tabs",
            draggable = False,
            deletable = False,
            collapsible= False,
            pre_content = _('Advanced configuration'),
            children = (
                modules.ModelList(
                    title=_('Auth'),
                    css_classes = ('dbmodule-content_auth',),
                    include_list=[
                        'django.contrib.auth',
                        ]),
                modules.ModelList(
                    title=_('Registration'),
                    css_classes = ('dbmodule-content_registration',),
                    include_list=[
                        'registration',
                        ]),
                modules.LinkList(
                    title=_('Site'),
                    css_classes = ('dbmodule-content_sites',),
                    children=[
                        {'title': _('Site'),
                         'url': '/admin/sites/site/%s/' % get_singleton(Site).id,
                         }
                        ]),
                )))

    ## RIGHT PANEL MODULES ##

        ## append a link list module for "quick links"
        quick_links = modules.LinkList(
            title=_('Quick links'),
            css_classes = ('right-area-modules',),
            layout = 'inline',
            draggable = False,
            deletable = False,
            collapsible= False,
            children=[
                {'title': _('Browse media files'),
                 'url': reverse('fb_browse'),
                 },
                {'title': _('Return to site'),
                 'url': '/',
                 'external': True,
                 },
                ]
        )

        # Comments moderation link
        from cyclope.apps.custom_comments import models as custom_comments_models
        if custom_comments_models.moderation_enabled():
            in_moderation = custom_comments_models.CustomComment.objects.in_moderation()
            if in_moderation:
                url = reverse('admin:comments_comment_changelist')
                url +="?is_removed__exact=0&is_public__exact=0"
                moderate_link = {
                    'title': _('%d comments need moderation') % len(in_moderation),
                    'url': url,
                    'external': False,
                }
                quick_links.children.insert(0, moderate_link)

        self.children.append(quick_links)

        # append a recent actions module
        self.children.append(modules.RecentActions(
            title=_('Recent Actions'),
            css_classes = ('dbmodule-recent-actions', 'right-area-modules'),
            draggable = False,
            deletable = False,
            collapsible= False,
            limit=5,
        ))

        self.children.append(modules.LinkList(
            title=_('Community and support'),
            css_classes = ('right-area-modules',),
            layout = 'inline',
            draggable = False,
            deletable = False,
            collapsible= False,
            children = [
                {
                    'title': _('Official website'),
                    'url': 'http://cyclope.codigosur.org',
                    'external': True,
                    },
                {
                    'title': _('Tutorials'),
                    'url': 'http://tutorialcyclope3.codigosur.net/',
                    'external': True,
                    },
                ]
        ))

        ## append a feed module
        # self.children.append(modules.Feed(
        #    title=_('Codigo Sur, latest news'),
        #    css_classes = ('dbmodule-feed', 'right-area-modules',),
        #    draggable = False,
        #    deletable = False,
        #    collapsible= False,
        #    feed_url='http://codigosur.org/rss.php/36',
        #    limit=6
        #))

    def get_module(self, title):
        """
        Get dashboard module by title.
        """
        for c in self.children:
            if c.title == title:
                return c
        raise ModuleNotFound(title)


class CustomAppIndexDashboard(AppIndexDashboard):
    """
    Custom app index dashboard for cyclope_project.
    """
    # we disable title because its redundant with the model list module
    title = ''

    def __init__(self, *args, **kwargs):
        AppIndexDashboard.__init__(self, *args, **kwargs)

        # append a model list module and a recent actions module
        self.children += [
            modules.ModelList(self.app_title, self.models),
            ## modules.RecentActions(
            ##     _('Recent Actions'),
            ##     include_list=self.get_app_content_types(),
            ##     limit=5
            ## )
        ]

    def init_with_context(self, context):
        """
        Use this method if you need to access the request context.
        """
        return super(CustomAppIndexDashboard, self).init_with_context(context)



# -*- coding: utf-8 -*-
#
# Copyright 2012 Código Sur Sociedad Civil
# All rights reserved.
#
# This file is part of Cyclope.
#
# Cyclope is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Cyclope is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

import os
import sys
import imp

from django.conf import settings
from django.core.exceptions import ObjectDoesNotExist, ImproperlyConfigured
from django.utils.translation import ugettext_lazy as _

_default_cache = None
_local_cache = None

_GLOBAL_CACHE = [True]

_DEFAULT_THEMES_ROOT = os.path.join(os.path.abspath(os.path.dirname(__file__)),
                                    "templates", "cyclope", "themes")

def _get_themes(path):
    names = [item for item in os.listdir(path) if os.path.isdir(os.path.join(path, item))]
    themes_ = {}
    for name in names:
        filename = os.path.join(path, name, "__init__.py")
        if os.path.exists(filename):
            themes_[name] = imp.load_source(name, filename)
    return themes_

def get_default_themes():
    global _default_cache
    path = unicode(_DEFAULT_THEMES_ROOT)
    if _default_cache is None:
        _default_cache = _get_themes(path)
    return _default_cache

def get_local_themes(cache=_GLOBAL_CACHE):
    global _local_cache
    if not hasattr(settings, 'CYCLOPE_LOCAL_THEMES_DIR'):
        return {}
    path = unicode(settings.CYCLOPE_LOCAL_THEMES_DIR)
    if _local_cache is None or not cache:
        _local_cache = _get_themes(path)
    return _local_cache

def get_all_themes(cache_local=_GLOBAL_CACHE):
    """
    Returns a dictionary with all themes. Key are the theme name (directory name)
    and value the module object.
    """
    all_themes = get_default_themes()
    all_themes.update(get_local_themes(cache_local))
    return all_themes

def get_theme(name):
    """
    Get a theme module by its name.
    """
    return get_all_themes().get(name, None)

def set_global_cache():
    global _GLOBAL_CACHE
    if not _GLOBAL_CACHE:
        _GLOBAL_CACHE.append(True)

def deactivate_global_cache():
    global _GLOBAL_CACHE
    if _GLOBAL_CACHE:
        _GLOBAL_CACHE.pop()

if hasattr(settings, 'CYCLOPE_LOCAL_THEMES_DIR'):
    if not hasattr(settings, 'CYCLOPE_LOCAL_THEMES_MEDIA_PREFIX'):
        raise ImproperlyConfigured(_('You need to set CYCLOPE_LOCAL_THEMES_PREFIX'\
                                      ' in your settings file'))


    if not os.path.exists(settings.CYCLOPE_LOCAL_THEMES_DIR):
        raise ImproperlyConfigured(_('Your CYCLOPE_LOCAL_THEMES_DIR' \
                                      'setting is invalid'))



#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
# Copyright 2010-2012 Código Sur Sociedad Civil
# All rights reserved.
#
# This file is part of Cyclope.
#
# Cyclope is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Cyclope is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

"""
utils
-----

Helper methods and classes.
"""

from django.contrib.contenttypes.models import ContentType
from django.core.paginator import InvalidPage, EmptyPage
from django.db.models import Q
from django.utils.translation import ugettext_lazy as _
from crispy_forms.helper import FormHelper
from crispy_forms.layout import Submit
import cyclope

def menu_item_for_request(request):
    # Avoids a circular import
    from cyclope.models import MenuItem
    if getattr(request, "_menu_item", False) is not False:
        return request._menu_item
    req_url = request.path
    url = req_url[len(cyclope.settings.CYCLOPE_PREFIX)+1:]
    if url == '':
        try:
            # when no home menuitem has yet been set this will fail
            menu_item = MenuItem.objects.select_related().get(site_home=True)
        except:
            menu_item = None
    else:
        try:
            # match menuitems with internal and external (custom) urls
            menu_item = MenuItem.objects.select_related().get(Q(url=url)|Q(url=req_url))
        except:
            menu_item = None
    request._menu_item = menu_item
    return menu_item

def layout_for_request(request):
    """
    Returns the layout corresponding to the MenuItem matching the request URL
    or the default site layout if no matching MenuItem is found.
    """
    menu_item = menu_item_for_request(request)
    if menu_item:
        layout = menu_item.get_layout()
    else:
        if request.session.has_key('layout'):
            layout = request.session['layout']
        else:
            layout = cyclope.settings.CYCLOPE_DEFAULT_LAYOUT

    return layout


def template_for_request(request):
    """
    Returns the template corresponding to the MenuItem.layout
    matching the request or the default site template
    if no matching MenuItem is found.
    """
    layout = layout_for_request(request)
    template = 'cyclope/themes/%s/%s' % (
                cyclope.settings.CYCLOPE_CURRENT_THEME,
                layout.template
                )
    return template


from django.utils.functional import Promise
from django.utils.translation import force_unicode
from django.utils.simplejson import JSONEncoder

# snippet from http://code.djangoproject.com/ticket/5868
# to fix json encoding of lazy translated strings
class LazyJSONEncoder(JSONEncoder):
    def default(self, o):
        if isinstance(o, Promise):
            return force_unicode(o)
        else:
            return super(LazyJSONEncoder, self).default(o)

# copied from django.templates.defaultfilters
def slugify(value):
    """
    Normalizes string, converts to lowercase, removes non-alpha characters,
    and converts spaces to hyphens.
    """
    import unicodedata, re
    value = unicode(value)
    value = unicodedata.normalize('NFKD', value).encode('ascii', 'ignore')
    value = unicode(re.sub('[^\w\s-]', '', value).strip().lower())
    return re.sub('[-\s]+', '-', value)

import string
from django.core.paginator import InvalidPage, EmptyPage
import unicodedata

def remove_accents(string):
    nkfd_form = unicodedata.normalize('NFKD', unicode(string))
    only_ascii = nkfd_form.encode('ASCII', 'ignore')
    return only_ascii

class NamePaginator(object):
    """Pagination for string-based objects"""
    # Based on http://djangosnippets.org/snippets/1364/

    def __init__(self, object_list, on=None, per_page=25):
        self.object_list = object_list
        self.count = len(object_list)
        self.pages = []

        # chunk up the objects so we don't need to iterate over the whole list for each letter
        chunks = {}

        for obj in self.object_list:
            if on:
                if "." in on:
                    obj_str = unicode(reduce(getattr, on.split("."), obj))
                else:
                    obj_str = unicode(getattr(obj, on))
            else: obj_str = unicode(obj)

            letter = remove_accents(obj_str[0]).upper()

            if letter not in chunks: chunks[letter] = []

            chunks[letter].append(obj)

        # the process for assigning objects to each page
        current_page = NamePage(self)

        for letter in string.ascii_uppercase:
            if letter not in chunks:
                current_page.add([], letter)
                continue

            sub_list = chunks[letter] # the items in object_list starting with this letter

            new_page_count = len(sub_list) + current_page.count
            # first, check to see if sub_list will fit or it needs to go onto a new page.
            # if assigning this list will cause the page to overflow...
            # and an underflow is closer to per_page than an overflow...
            # and the page isn't empty (which means len(sub_list) > per_page)...
            if new_page_count > per_page and \
                    abs(per_page - current_page.count) < abs(per_page - new_page_count) and \
                    current_page.count > 0:
                # make a new page
                self.pages.append(current_page)
                current_page = NamePage(self)

            current_page.add(sub_list, letter)

        # if we finished the for loop with a page that isn't empty, add it
        if current_page.count > 0: self.pages.append(current_page)

    def page(self, num):
        """Returns a Page object for the given 1-based page number."""
        if len(self.pages) == 0:
            return NamePage(self)
        elif num > 0 and num <= len(self.pages):
            return self.pages[num-1]
        else:
            raise InvalidPage

    @property
    def num_pages(self):
        """Returns the total number of pages"""
        return len(self.pages)

class NamePage(object):
    def __init__(self, paginator):
        self.paginator = paginator
        self.object_list = []
        self.letters = []

    @property
    def count(self):
        return len(self.object_list)

    @property
    def start_letter(self):
        if len(self.letters) > 0:
            self.letters.sort(key=str.upper)
            return self.letters[0]
        else: return None

    @property
    def end_letter(self):
        if len(self.letters) > 0:
            self.letters.sort(key=str.upper)
            return self.letters[-1]
        else: return None

    @property
    def number(self):
        return self.paginator.pages.index(self) + 1

    def add(self, new_list, letter=None):
        if len(new_list) > 0: self.object_list = self.object_list + new_list
        if letter: self.letters.append(letter)

    def __repr__(self):
        if not self.start_letter:
            return "<Page: empty>"
        if self.start_letter == self.end_letter:
            return u"%c" % (self.start_letter, )
        else:
            return u'%c-%c' % (self.start_letter, self.end_letter)

def get_page(paginator, request):
    """
    Returns the current paginator instance page. Page number of paginator
    is determined by request.GET["page"].
    """
    # Make sure page request is an int. If not, deliver first page.
    try:
        page_number = int(request.GET.get('page', '1'))
    except ValueError:
        page_number = 1

    # DjangoDocs uses page differently
    # If page request (9999) is out of range, deliver last page of results.
    try:
        page = paginator.page(page_number)
    except (EmptyPage, InvalidPage):
        page = paginator.page(paginator.num_pages)

    return page




def _invalidate_cache(sender, **kwargs):
    sender._instance = None

def get_singleton(model_class):
    """
    Returns the instance with id=1 of the Model Class
    """
    from django.db.models.signals import post_save
    try:
        if not hasattr(model_class, "_instance"):
            post_save.connect(_invalidate_cache, sender=model_class)
        if not getattr(model_class, "_instance", None):
            model_class._instance = model_class.objects.get(id=1)
        return model_class._instance
    except model_class.DoesNotExist, e:
        e.args = (e.args[0] +" At least one instance of this class must exists.", )
        raise e

def get_or_set_cache(func, args, kwargs, key, timeout=None):
    from django.core.cache import cache
    out = cache.get(key)
    if out is None:
        out = func(*args, **kwargs)
        cache.set(key, out, timeout)
    return out

class PermanentFilterMixin(object):
    """
    Mixin class that adds a default filter to a changelist that also is permanent
    (saved in the session).

    You must define permanent_filters in the subclass, something like this:

    permanent_filters = (
        (u"model__id__exact", # this is the key of the filter
         lambda request: unicode(Model.objects.all()[0].id)), # default param as lambda
    )

    And then use the method do_permanent_filters in the change_list
    """
    permanent_filters = None

    def do_permanent_filters(self, request):
        for filter_key, default_filter_param in self.permanent_filters:
            session_key = "%s|%s" % (request.path, filter_key)
            if not request.GET.get(filter_key):
                param = request.session.get(session_key) or default_filter_param(request)
                if param:
                    GET = request.GET.copy()
                    GET[filter_key] = param
                    request.GET = GET
            request.session[session_key] = request.GET.get(filter_key)


class ThumbnailMixin(object):

    def get_thumbnail_src(self):
        try:
            image = getattr(self, "image")
        except AttributeError:
            raise NotImplemented
        return getattr(image, "url_thumbnail")

    def thumbnail(self):
        return '<img class="thumbnail" src="%s"/>' %  self.get_thumbnail_src()

    thumbnail.short_description = _('Thumbnail Image')
    thumbnail.allow_tags = True


class CrispyFormsSimpleMixin(object):
    helper = FormHelper()
    helper.add_input(Submit('submit', _('Submit')))



#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
# Copyright 2010-2012 Código Sur Sociedad Civil.
# All rights reserved.
#
# This file is part of Cyclope.
#
# Cyclope is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Cyclope is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from django.contrib import admin
from django.core import urlresolvers
from django.utils.translation import ugettext_lazy as _
from django.contrib.comments.admin import CommentsAdmin
from django.contrib.comments.models import Comment

from models import CustomComment

class CustomCommentsAdmin(CommentsAdmin):
    fieldsets = (
        (None,
           {'fields': ('content_type', 'object_pk')}
        ),
        (_('Content'),
           {'fields': ('user', 'user_name', 'user_email', 'user_url', 'comment')}
        ),
        (_('Metadata'),
           {'fields': ('submit_date', 'ip_address', 'is_public', 'is_removed')}
        ),
     )
    list_display = ('name', "content", "content_url", 'content_type', 'ip_address',
                    'submit_date', 'is_public', 'is_removed')
    list_filter = ('submit_date', 'is_public', 'is_removed')

    def get_actions(self, request):
        base_actions = super(CustomCommentsAdmin, self).actions
        if "flag_comments" in base_actions:
            base_actions.remove("flag_comments")
        actions = super(CustomCommentsAdmin, self).get_actions(request)
        return actions

    def content(self, obj):
        admin_url_name = "%s_%s_change" % (obj.content_type.app_label, obj.content_type.name)
        admin_url_name = admin_url_name.replace(" ", "")
        change_url = urlresolvers.reverse('admin:%s' % admin_url_name, args=(obj.content_object.id,))
        return "<a href='%s'>%s</a>" % (change_url, obj.content_object)
    content.allow_tags = True

    def content_url(self, obj):
        url = obj.content_object.get_absolute_url()
        return  "<a href='%s'>%s</a>" % (url, url)
    content_url.allow_tags = True

try:
    admin.site.unregister(Comment)
except admin.sites.NotRegistered:
    pass
admin.site.register(Comment, CustomCommentsAdmin)
